import { Extension } from '@tiptap/core';
import '@tiptap/extension-text-style';
export const FontSize = Extension.create({
    name: 'fontSize',
    addOptions () {
        return {
            types: [
                'textStyle'
            ]
        };
    },
    addGlobalAttributes () {
        return [
            {
                types: [
                    'paragraph'
                ],
                attributes: {
                    class: {}
                }
            },
            {
                types: this.options.types,
                attributes: {
                    fontSize: {
                        parseHTML: (element)=>element.style.fontSize.replace(/['"]+/g, ''),
                        renderHTML: (attributes)=>{
                            if (!attributes.fontSize) {
                                return {};
                            }
                            return {
                                style: `font-size: ${attributes.fontSize}`
                            };
                        }
                    }
                }
            }
        ];
    },
    addCommands () {
        return {
            setFontSize: (fontSize)=>({ chain })=>chain().setMark('textStyle', {
                        fontSize
                    }).run(),
            unsetFontSize: ()=>({ chain })=>chain().setMark('textStyle', {
                        fontSize: null
                    }).removeEmptyTextStyle().run()
        };
    }
});
export default FontSize;

//# sourceMappingURL=FontSize.js.map