import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { BubbleMenu as BaseBubbleMenu } from "@tiptap/react";
import { useCallback, useRef } from "react";
import { sticky } from "tippy.js";
import { v4 as uuid } from "uuid";
import { AlignHorizontalDistributeCenter, AlignHorizontalDistributeEnd, AlignHorizontalDistributeStart } from "lucide-react";
import { Icon } from "../../../features/ui/Icon.js";
import { Toolbar } from "../../../features/ui/Toolbar.js";
import { getRenderContainer } from "../../../lib/utils/index.js";
import { ImageBlockWidth } from "./ImageBlockWidth.js";
import i18next from "i18next";
export const ImageBlockMenu = ({ editor, appendTo })=>{
    const menuRef = useRef(null);
    const tippyInstance = useRef(null);
    const getReferenceClientRect = useCallback(()=>{
        const renderContainer = getRenderContainer(editor, "node-imageBlock");
        const rect = renderContainer?.getBoundingClientRect() || new DOMRect(-1000, -1000, 0, 0);
        return rect;
    }, [
        editor
    ]);
    const shouldShow = useCallback(()=>{
        const isActive = editor.isActive("imageBlock");
        return isActive;
    }, [
        editor
    ]);
    const onAlignImageLeft = useCallback(()=>{
        editor.chain().focus(undefined, {
            scrollIntoView: false
        }).setImageBlockAlign("left").run();
    }, [
        editor
    ]);
    const onAlignImageCenter = useCallback(()=>{
        editor.chain().focus(undefined, {
            scrollIntoView: false
        }).setImageBlockAlign("center").run();
    }, [
        editor
    ]);
    const onAlignImageRight = useCallback(()=>{
        editor.chain().focus(undefined, {
            scrollIntoView: false
        }).setImageBlockAlign("right").run();
    }, [
        editor
    ]);
    const onWidthChange = useCallback((value)=>{
        editor.chain().focus(undefined, {
            scrollIntoView: false
        }).setImageBlockWidth(value).run();
    }, [
        editor
    ]);
    return /*#__PURE__*/ _jsx(BaseBubbleMenu, {
        editor: editor,
        pluginKey: `imageBlockMenu-${uuid()}`,
        shouldShow: shouldShow,
        updateDelay: 0,
        tippyOptions: {
            offset: [
                0,
                8
            ],
            popperOptions: {
                modifiers: [
                    {
                        name: "flip",
                        enabled: false
                    }
                ]
            },
            getReferenceClientRect,
            onCreate: (instance)=>{
                tippyInstance.current = instance;
            },
            appendTo: ()=>{
                return appendTo?.current;
            },
            plugins: [
                sticky
            ],
            sticky: "popper"
        },
        children: /*#__PURE__*/ _jsxs(Toolbar.Wrapper, {
            shouldShowContent: shouldShow(),
            ref: menuRef,
            children: [
                /*#__PURE__*/ _jsx(Toolbar.Button, {
                    type: "button",
                    tooltip: i18next.t("alignImageLeft") || "Align image left",
                    active: editor.isActive("imageBlock", {
                        align: "left"
                    }),
                    onClick: onAlignImageLeft,
                    children: /*#__PURE__*/ _jsx(Icon, {
                        icon: AlignHorizontalDistributeStart
                    })
                }),
                /*#__PURE__*/ _jsx(Toolbar.Button, {
                    type: "button",
                    tooltip: i18next.t("alignImageCenter") || "Align image center",
                    active: editor.isActive("imageBlock", {
                        align: "center"
                    }),
                    onClick: onAlignImageCenter,
                    children: /*#__PURE__*/ _jsx(Icon, {
                        icon: AlignHorizontalDistributeCenter
                    })
                }),
                /*#__PURE__*/ _jsx(Toolbar.Button, {
                    type: "button",
                    tooltip: i18next.t("alignImageRight") || "Align image right",
                    active: editor.isActive("imageBlock", {
                        align: "right"
                    }),
                    onClick: onAlignImageRight,
                    children: /*#__PURE__*/ _jsx(Icon, {
                        icon: AlignHorizontalDistributeEnd
                    })
                }),
                /*#__PURE__*/ _jsx(Toolbar.Divider, {}),
                /*#__PURE__*/ _jsx(ImageBlockWidth, {
                    onChange: onWidthChange,
                    value: parseInt(editor.getAttributes("imageBlock").width)
                })
            ]
        })
    });
};
export default ImageBlockMenu;

//# sourceMappingURL=ImageBlockMenu.js.map