import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Image, Upload } from "lucide-react";
import { useCallback } from "react";
import { Button } from "../../../features/ui/Button/Button.js";
import { Icon } from "../../../features/ui/Icon.js";
import { Spinner } from "../../../features/ui/Spinner/Spinner.js";
import { cn } from "../../../lib/utils/index.js";
import { useDropZone, useFileUpload, useUploader } from "./hooks.js";
export const ImageUploader = ({ onUpload })=>{
    const { loading, uploadFile } = useUploader({
        onUpload
    });
    const { handleUploadClick, ref } = useFileUpload();
    const { draggedInside, onDrop, onDragEnter, onDragLeave } = useDropZone({
        uploader: uploadFile
    });
    const onFileChange = useCallback((e)=>e.target.files ? uploadFile() : null, [
        uploadFile
    ]);
    if (loading) {
        return /*#__PURE__*/ _jsx("div", {
            className: "flex items-center justify-center p-8 rounded-lg min-h-[10rem] bg-opacity-80",
            children: /*#__PURE__*/ _jsx(Spinner, {
                className: "text-neutral-500",
                size: 1.5
            })
        });
    }
    const wrapperClass = cn("flex flex-col items-center justify-center px-8 py-10 rounded-lg bg-opacity-80", draggedInside && "bg-neutral-100");
    return /*#__PURE__*/ _jsxs("div", {
        className: wrapperClass,
        onDrop: onDrop,
        onDragOver: onDragEnter,
        onDragLeave: onDragLeave,
        children: [
            /*#__PURE__*/ _jsx(Icon, {
                icon: Image,
                className: "w-12 h-12 mb-4 text-black dark:text-white opacity-20"
            }),
            /*#__PURE__*/ _jsxs("div", {
                className: "flex flex-col items-center justify-center gap-2",
                children: [
                    /*#__PURE__*/ _jsx("div", {
                        className: "text-sm font-medium text-center text-neutral-400 dark:text-neutral-500",
                        children: draggedInside ? "Drop image here" : "Drag and drop or"
                    }),
                    /*#__PURE__*/ _jsx("div", {
                        children: /*#__PURE__*/ _jsxs(Button, {
                            type: "button",
                            disabled: draggedInside,
                            onClick: handleUploadClick,
                            variant: "primary",
                            buttonSize: "small",
                            children: [
                                /*#__PURE__*/ _jsx(Icon, {
                                    icon: Upload
                                }),
                                "Upload an image"
                            ]
                        })
                    })
                ]
            }),
            /*#__PURE__*/ _jsx("input", {
                className: "w-0 h-0 overflow-hidden opacity-0",
                ref: ref,
                type: "file",
                accept: ".jpg,.jpeg,.png,.webp,.gif",
                onChange: onFileChange
            })
        ]
    });
};
export default ImageUploader;

//# sourceMappingURL=ImageUploader.js.map