import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { BubbleMenu as BaseBubbleMenu } from "@tiptap/react";
import { useCallback } from "react";
import { sticky } from "tippy.js";
import { v4 as uuid } from "uuid";
import { Columns2, PanelLeft, PanelRight } from "lucide-react";
import { Icon } from "../../../features/ui/Icon.js";
import { Toolbar } from "../../../features/ui/Toolbar.js";
import { getRenderContainer } from "../../../lib/utils/index.js";
import { ColumnLayout } from "../Columns.js";
import i18next from "i18next";
export const ColumnsMenu = ({ editor, appendTo })=>{
    const getReferenceClientRect = useCallback(()=>{
        const renderContainer = getRenderContainer(editor, "columns");
        const rect = renderContainer?.getBoundingClientRect() || new DOMRect(-1000, -1000, 0, 0);
        return rect;
    }, [
        editor
    ]);
    const shouldShow = useCallback(()=>{
        const isColumns = editor.isActive("columns");
        return isColumns;
    }, [
        editor
    ]);
    const onColumnLeft = useCallback(()=>{
        editor.chain().focus().setLayout(ColumnLayout.SidebarLeft).run();
    }, [
        editor
    ]);
    const onColumnRight = useCallback(()=>{
        editor.chain().focus().setLayout(ColumnLayout.SidebarRight).run();
    }, [
        editor
    ]);
    const onColumnTwo = useCallback(()=>{
        editor.chain().focus().setLayout(ColumnLayout.TwoColumn).run();
    }, [
        editor
    ]);
    return /*#__PURE__*/ _jsx(BaseBubbleMenu, {
        editor: editor,
        pluginKey: `columnsMenu-${uuid()}`,
        shouldShow: shouldShow,
        updateDelay: 0,
        tippyOptions: {
            offset: [
                0,
                8
            ],
            popperOptions: {
                modifiers: [
                    {
                        name: "flip",
                        enabled: false
                    }
                ]
            },
            getReferenceClientRect,
            appendTo: ()=>appendTo?.current,
            plugins: [
                sticky
            ],
            sticky: "popper"
        },
        children: /*#__PURE__*/ _jsxs(Toolbar.Wrapper, {
            children: [
                /*#__PURE__*/ _jsx(Toolbar.Button, {
                    type: "button",
                    tooltip: i18next.t("sidebarLeft") || "Sidebar left",
                    active: editor.isActive("columns", {
                        layout: ColumnLayout.SidebarLeft
                    }),
                    onClick: onColumnLeft,
                    children: /*#__PURE__*/ _jsx(Icon, {
                        icon: PanelLeft
                    })
                }),
                /*#__PURE__*/ _jsx(Toolbar.Button, {
                    type: "button",
                    tooltip: i18next.t("twoColumns") || "Two columns",
                    active: editor.isActive("columns", {
                        layout: ColumnLayout.TwoColumn
                    }),
                    onClick: onColumnTwo,
                    children: /*#__PURE__*/ _jsx(Icon, {
                        icon: Columns2
                    })
                }),
                /*#__PURE__*/ _jsx(Toolbar.Button, {
                    type: "button",
                    tooltip: i18next.t("sidebarRight") || "Sidebar right",
                    active: editor.isActive("columns", {
                        layout: ColumnLayout.SidebarRight
                    }),
                    onClick: onColumnRight,
                    children: /*#__PURE__*/ _jsx(Icon, {
                        icon: PanelRight
                    })
                })
            ]
        })
    });
};
export default ColumnsMenu;

//# sourceMappingURL=ColumnsMenu.js.map