import { Node, mergeAttributes } from '@tiptap/core';
import { ReactNodeViewRenderer } from '@tiptap/react';
import InstagramEmbed from './InstagramEmbed.js';
export const Instagram = Node.create({
    name: 'instagram',
    group: 'block',
    content: 'inline*',
    draggable: true,
    // content: 'inline*',
    addAttributes () {
        return {
            url: {
                default: null
            },
            class: {
                default: null
            },
            src: {
                default: null
            },
            width: {
                default: '328px'
            },
            height: {
                default: '550px'
            },
            frameborder: {
                default: '0'
            },
            scrolling: {
                default: 'no'
            },
            allowtransparency: {
                default: 'true'
            }
        };
    },
    parseHTML () {
        return [
            {
                tag: 'div[data-type="instagram"]'
            }
        ];
    },
    renderHTML ({ HTMLAttributes }) {
        return [
            "div",
            mergeAttributes(HTMLAttributes, {
                "data-type": "instagram",
                class: `react-renderer node-instagram ${HTMLAttributes.class ?? ""}`
            }),
            [
                'div',
                mergeAttributes({
                    class: 'socialMediaContainer'
                }),
                [
                    'div',
                    mergeAttributes({
                        class: 'rsme-embed rsme-instagram-embed'
                    }),
                    [
                        'blockquote',
                        mergeAttributes(HTMLAttributes, {
                            class: 'instagram-media',
                            style: "background:#FFF; border:0; margin:1px; max-width:540px; width:99.375%; width:-webkit-calc(100% - 2px); width:calc(100% - 2px);",
                            "data-instgrm-captioned": true,
                            "data-instgrm-permalink": `${convertInstaUrlToEmbed(HTMLAttributes.url)}?utm_source=ig_embed&utm_campaign=loading`,
                            "data-instgrm-version": "14"
                        }),
                        [
                            'div',
                            {
                                class: 'instagram-media-pre-embed rsme-d-none'
                            }
                        ]
                    ],
                    [
                        'script',
                        {
                            async: true,
                            src: 'https://www.instagram.com/embed.js',
                            charset: 'utf-8',
                            onload: `() => {
                    if (window.instgrm) {
                      window.instgrm.Embeds.process();
                    }
                }`
                        }
                    ]
                ]
            ]
        ];
    },
    addKeyboardShortcuts () {
        return {
            'Mod-Enter': ()=>{
                return this.editor.chain().insertContentAt(this.editor.state.selection.head, {
                    type: this.type.name
                }).focus().run();
            }
        };
    },
    addNodeView () {
        return ReactNodeViewRenderer(InstagramEmbed);
    },
    addCommands () {
        return {
            insertInstagram: (url, className)=>({ commands, state })=>{
                    let embedUrl = "";
                    if (url) {
                        embedUrl = convertInstaUrlToEmbed(url);
                    }
                    return commands.insertContent({
                        type: 'instagram',
                        attrs: {
                            url: url,
                            class: className,
                            src: embedUrl
                        }
                    });
                }
        };
    }
});
function convertInstaUrlToEmbed(url) {
    if (!url) return undefined;
    try {
        const urlWithNoQueryOrUsername = url.split(/[?#]/)[0].replace(/\.com\/.*?\/p/, '.com/p').replace(/\.com\/.*?\/reel/, '.com/reel');
        const cleanUrlWithEndingSlash = `${urlWithNoQueryOrUsername}${urlWithNoQueryOrUsername.endsWith('/') ? '' : '/'}`;
        return cleanUrlWithEndingSlash;
    } catch  {
        return undefined;
    }
}
function isValidHttpUrl(string) {
    let url;
    try {
        url = new URL(string);
    } catch (_) {
        return false;
    }
    return url.protocol === 'http:' || url.protocol === 'https:';
}

//# sourceMappingURL=instagram.js.map