import { Node, mergeAttributes } from '@tiptap/core';
import { ReactNodeViewRenderer } from '@tiptap/react';
import TiktokEmbed from './TiktokEmbed.js';
export const Tiktok = Node.create({
    name: 'tiktok',
    group: 'block',
    content: 'inline*',
    draggable: true,
    // content: 'inline*',
    addAttributes () {
        return {
            url: {
                default: null
            },
            class: {
                default: null
            },
            src: {
                default: null
            },
            width: {
                default: '328px'
            },
            height: {
                default: '550px'
            },
            frameborder: {
                default: '0'
            },
            scrolling: {
                default: 'no'
            },
            allowtransparency: {
                default: 'true'
            }
        };
    },
    parseHTML () {
        return [
            {
                tag: 'div[data-type="tiktok"]'
            }
        ];
    },
    renderHTML ({ HTMLAttributes }) {
        return [
            "div",
            mergeAttributes({
                "data-type": "tiktok",
                class: `react-renderer node-tiktok ${HTMLAttributes.class ?? ""}`
            }),
            [
                'div',
                mergeAttributes({
                    class: 'socialMediaContainer'
                }),
                [
                    'div',
                    mergeAttributes({
                        class: 'rsme-embed rsme-tiktok-embed',
                        style: 'overflow: hidden; border-radius: 8px;'
                    }),
                    [
                        'div',
                        {
                            class: 'tiktok-embed-container'
                        },
                        [
                            'iframe',
                            mergeAttributes(HTMLAttributes, {
                                src: convertTikTokUrlToEmbed(HTMLAttributes.url)
                            })
                        ]
                    ]
                ]
            ]
        ];
    },
    addKeyboardShortcuts () {
        return {
            'Mod-Enter': ()=>{
                return this.editor.chain().insertContentAt(this.editor.state.selection.head, {
                    type: this.type.name
                }).focus().run();
            }
        };
    },
    addNodeView () {
        return ReactNodeViewRenderer(TiktokEmbed);
    },
    addCommands () {
        return {
            insertTiktok: (url, className)=>({ commands, state })=>{
                    let embedUrl;
                    // Usage in the original location:
                    embedUrl = url ? convertTikTokUrlToEmbed(url) : undefined;
                    return commands.insertContent({
                        type: 'tiktok',
                        attrs: {
                            url,
                            class: className,
                            src: embedUrl
                        }
                    });
                }
        };
    }
});
function convertTikTokUrlToEmbed(url) {
    if (!url) return undefined;
    try {
        const urlObj = new URL(url);
        const path = urlObj.pathname;
        const videoId = path.split('/').filter(Boolean)[2];
        return videoId ? `https://www.tiktok.com/embed/v3/${videoId}` : undefined;
    } catch  {
        return undefined;
    }
}
function isValidHttpUrl(string) {
    let url;
    try {
        url = new URL(string);
    } catch (_) {
        return false;
    }
    return url.protocol === 'http:' || url.protocol === 'https:';
}

//# sourceMappingURL=tiktok.js.map