import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { BubbleMenu as BaseBubbleMenu } from "@tiptap/react";
import { useCallback, useRef } from "react";
import { sticky } from "tippy.js";
import { v4 as uuid } from "uuid";
import { AlignHorizontalDistributeCenter, AlignHorizontalDistributeEnd, AlignHorizontalDistributeStart, Pencil, PencilOff } from "lucide-react";
import { Icon } from "../../../features/ui/Icon.js";
import { Toolbar } from "../../../features/ui/Toolbar.js";
import { getRenderContainer } from "../../../lib/utils/index.js";
import { VideoBlockWidth } from "./VideoBlockWidth.js";
import i18next from "i18next";
export const VideoBlockMenu = ({ editor, appendTo })=>{
    const menuRef = useRef(null);
    const tippyInstance = useRef(null);
    const getReferenceClientRect = useCallback(()=>{
        const renderContainer = getRenderContainer(editor, "node-videoBlock");
        const rect = renderContainer?.getBoundingClientRect() || new DOMRect(-1000, -1000, 0, 0);
        return rect;
    }, [
        editor
    ]);
    const shouldShow = useCallback(()=>{
        const isActive = editor.isActive("videoBlock");
        return isActive;
    }, [
        editor
    ]);
    const onAlignVideoLeft = useCallback(()=>{
        editor.chain().focus(undefined, {
            scrollIntoView: false
        }).setVideoBlockAlign("left").run();
    }, [
        editor
    ]);
    const onAlignVideoCenter = useCallback(()=>{
        editor.chain().focus(undefined, {
            scrollIntoView: false
        }).setVideoBlockAlign("center").run();
    }, [
        editor
    ]);
    const onAlignVideoRight = useCallback(()=>{
        editor.chain().focus(undefined, {
            scrollIntoView: false
        }).setVideoBlockAlign("right").run();
    }, [
        editor
    ]);
    const onHideCaption = useCallback(()=>{
        editor.chain().focus(undefined, {
            scrollIntoView: false
        }).setVideoBlockCaption(editor.isActive("videoBlock", {
            caption: false
        }) ? true : false).run();
    }, [
        editor
    ]);
    const onWidthChange = useCallback((value)=>{
        editor.chain().focus(undefined, {
            scrollIntoView: false
        }).setVideoBlockWidth(value).run();
    }, [
        editor
    ]);
    return /*#__PURE__*/ _jsx(BaseBubbleMenu, {
        editor: editor,
        pluginKey: `videoBlockMenu-${uuid()}`,
        shouldShow: shouldShow,
        updateDelay: 0,
        tippyOptions: {
            offset: [
                0,
                8
            ],
            popperOptions: {
                modifiers: [
                    {
                        name: "flip",
                        enabled: false
                    }
                ]
            },
            getReferenceClientRect,
            onCreate: (instance)=>{
                tippyInstance.current = instance;
            },
            appendTo: ()=>{
                return appendTo?.current;
            },
            plugins: [
                sticky
            ],
            sticky: "popper"
        },
        children: /*#__PURE__*/ _jsxs(Toolbar.Wrapper, {
            shouldShowContent: shouldShow(),
            ref: menuRef,
            children: [
                /*#__PURE__*/ _jsx(Toolbar.Button, {
                    type: "button",
                    tooltip: i18next.t("toggleCaption") || "Hide/Show caption",
                    active: editor.isActive("videoBlock", {
                        caption: false
                    }),
                    onClick: onHideCaption,
                    children: /*#__PURE__*/ _jsx(Icon, {
                        icon: editor.isActive("videoBlock", {
                            caption: false
                        }) ? PencilOff : Pencil
                    })
                }),
                /*#__PURE__*/ _jsx(Toolbar.Button, {
                    type: "button",
                    tooltip: i18next.t("alignVideoLeft") || "Align video left",
                    active: editor.isActive("videoBlock", {
                        align: "left"
                    }),
                    onClick: onAlignVideoLeft,
                    children: /*#__PURE__*/ _jsx(Icon, {
                        icon: AlignHorizontalDistributeStart
                    })
                }),
                /*#__PURE__*/ _jsx(Toolbar.Button, {
                    type: "button",
                    tooltip: i18next.t("alignVideoCenter") || "Align video center",
                    active: editor.isActive("videoBlock", {
                        align: "center"
                    }),
                    onClick: onAlignVideoCenter,
                    children: /*#__PURE__*/ _jsx(Icon, {
                        icon: AlignHorizontalDistributeCenter
                    })
                }),
                /*#__PURE__*/ _jsx(Toolbar.Button, {
                    type: "button",
                    tooltip: i18next.t("alignVideoRight") || "Align video right",
                    active: editor.isActive("videoBlock", {
                        align: "right"
                    }),
                    onClick: onAlignVideoRight,
                    children: /*#__PURE__*/ _jsx(Icon, {
                        icon: AlignHorizontalDistributeEnd
                    })
                }),
                /*#__PURE__*/ _jsx(Toolbar.Divider, {}),
                /*#__PURE__*/ _jsx(VideoBlockWidth, {
                    onChange: onWidthChange,
                    value: parseInt(editor.getAttributes("videoBlock").width)
                })
            ]
        })
    });
};
export default VideoBlockMenu;

//# sourceMappingURL=VideoBlockMenu.js.map