import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { NodeViewWrapper } from "@tiptap/react";
import React, { useCallback, useEffect, useMemo, useRef } from "react";
import { cn } from "../../../lib/utils/index.js";
import VideoPlayer from "./videojs/VideoPlayer.js";
export const VideoBlockView = (props)=>{
    const { editor, getPos, node } = props;
    const videoWrapperRef = useRef(null);
    const { src, poster, playlistUrl, caption, title } = node.attrs;
    const [playlistContent, setPlaylistContent] = React.useState();
    const [error, setError] = React.useState("");
    useEffect(()=>{
        async function getPlaylistContent() {
            try {
                const res = await fetch(playlistUrl, {
                    cache: "no-cache"
                });
                return await res.json();
            } catch  {
                setError("Issue with getting asset info");
                return undefined;
            }
        }
        if (playlistUrl) {
            try {
                getPlaylistContent().then((data)=>{
                    setPlaylistContent(data);
                }).catch((err)=>{
                    setError(err);
                });
            } catch (error) {
                setError(error);
            }
        }
    }, [
        playlistUrl
    ]);
    const wrapperClassName = cn(node.attrs.align === "left" ? "ml-0" : "ml-auto", node.attrs.align === "right" ? "mr-0" : "mr-auto", node.attrs.align === "center" && "mx-auto");
    const onClick = useCallback(()=>{
        editor.commands.setNodeSelection(getPos());
    }, [
        getPos,
        editor.commands
    ]);
    const videoJsOptions = useMemo(()=>{
        if (playlistContent == undefined) return {};
        if (playlistContent.items.some((item)=>item.type === "application/x-mpegURL" || item.type === "application/vnd.apple.mpegurl")) {
            return {
                sources: playlistContent.items.filter((item)=>item.type === "application/x-mpegURL" || item.type === "application/vnd.apple.mpegurl").map((item)=>({
                        src: item.src,
                        type: item.type,
                        label: item.label
                    })),
                poster: playlistContent.poster
            };
        }
        return {
            sources: playlistContent.items.map((item)=>({
                    src: item.src,
                    type: item.type,
                    label: item.label
                })),
            poster: playlistContent.poster
        };
    }, [
        playlistContent
    ]);
    return /*#__PURE__*/ _jsx(NodeViewWrapper, {
        children: /*#__PURE__*/ _jsx("div", {
            className: wrapperClassName,
            style: {
                width: node.attrs.width
            },
            children: /*#__PURE__*/ _jsxs("div", {
                ref: videoWrapperRef,
                children: [
                    error && /*#__PURE__*/ _jsx("div", {
                        children: error
                    }),
                    playlistContent && /*#__PURE__*/ _jsx(VideoPlayer, {
                        options: videoJsOptions
                    }),
                    caption && playlistContent?.title && /*#__PURE__*/ _jsx("caption", {
                        className: "text-center block text-sm text-gray-500",
                        children: title || playlistContent?.title
                    })
                ]
            })
        })
    });
};
export default VideoBlockView;

//# sourceMappingURL=VideoBlockView.js.map