import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { NodeViewWrapper } from "@tiptap/react";
import React, { useEffect, useMemo, useRef } from "react";
import { cn } from "../../../lib/utils/index.js";
import VideoPlayer from "./videojs/VideoPlayer.js";
import { useGetAssetsAspectRatio } from "../../serverside/getAssetsAspectRatio.js";
export const VideoBlockViewClientside = ({ className, getVideoAspect, ...props })=>{
    const { node } = props;
    const videoWrapperRef = useRef(null);
    const { src, poster, playlistUrl, caption, actualWidth, actualHeight } = node.attrs;
    const { aspectRatio, calculateAspectRatio } = useGetAssetsAspectRatio();
    const [playlistContent, setPlaylistContent] = React.useState();
    const [error, setError] = React.useState();
    useEffect(()=>{
        async function getPlaylistContent() {
            const res = await fetch(playlistUrl, {
                cache: "no-cache"
            });
            return await res.json();
        }
        if (playlistUrl) {
            try {
                getPlaylistContent().then((data)=>{
                    setPlaylistContent(data);
                }).catch((err)=>{
                    setError(err);
                });
            } catch (error) {
                setError(error);
            }
        }
    }, [
        playlistUrl
    ]);
    const wrapperClassName = cn(node.attrs.align === "left" ? "ml-0" : "ml-auto", node.attrs.align === "right" ? "mr-0" : "mr-auto", node.attrs.align === "center" && "mx-auto");
    const videoJsOptions = useMemo(()=>{
        if (playlistContent == undefined) return {};
        if (playlistContent.items.some((item)=>item.type === "application/x-mpegURL" || item.type === "application/vnd.apple.mpegurl")) {
            return {
                sources: playlistContent.items.filter((item)=>item.type === "application/x-mpegURL" || item.type === "application/vnd.apple.mpegurl").map((item)=>({
                        src: item.src,
                        type: item.type,
                        label: item.label
                    })),
                poster: playlistContent.poster,
                preload: "auto"
            };
        }
        return {
            sources: playlistContent.items.map((item)=>({
                    src: item.src,
                    type: item.type,
                    label: item.label
                })),
            poster: playlistContent.poster,
            preload: "auto"
        };
    }, [
        playlistContent
    ]);
    useEffect(()=>{
        if (!playlistContent?.items?.length) {
            return;
        }
        const source = playlistContent.items.find((item)=>item.src);
        if (!aspectRatio && source?.src) {
            calculateAspectRatio({
                src: source.src,
                actualWidth: actualWidth || source?.width,
                actualHeight: actualHeight || source?.height
            }, "VIDEO", getVideoAspect);
        }
    }, [
        playlistContent
    ]);
    const style = useMemo(()=>{
        if (aspectRatio) {
            return {
                aspectRatio,
                maxHeight: "80vh",
                width: node.attrs.width
            };
        }
        return {
            width: node.attrs.width
        };
    }, [
        aspectRatio
    ]);
    return /*#__PURE__*/ _jsxs(NodeViewWrapper, {
        className: className,
        children: [
            /*#__PURE__*/ _jsxs("div", {
                className: cn(wrapperClassName, "main-videojs-wrapper aspect-square"),
                ref: videoWrapperRef,
                style: style,
                children: [
                    error && /*#__PURE__*/ _jsx("div", {
                        children: error
                    }),
                    playlistContent && /*#__PURE__*/ _jsx(VideoPlayer, {
                        options: videoJsOptions
                    })
                ]
            }),
            caption && playlistContent?.title && /*#__PURE__*/ _jsx("div", {
                className: "block mx-auto text-sm text-gray-500",
                style: {
                    width: node.attrs.width
                },
                children: playlistContent?.title
            })
        ]
    });
};
export default VideoBlockViewClientside;

//# sourceMappingURL=VideoBlockViewClientside.js.map