import { mergeAttributes, Node } from "@tiptap/core";
/**
 * Matches an image to a ![image](src "title") on input.
 */ export const inputRegex = /(?:^|\s)(!\[(.+|:?)]\((\S+)(?:(?:\s+)["'](\S+)["'])?\))$/;
/**
 * This extension allows you to insert images.
 * @see https://www.tiptap.dev/api/nodes/image
 */ export const VideoBlockServerside = Node.create({
    name: "videoBlock",
    addOptions () {
        return {
            inline: false,
            allowBase64: false,
            HTMLAttributes: {}
        };
    },
    inline () {
        return this.options.inline;
    },
    group () {
        return this.options.inline ? "inline" : "block";
    },
    draggable: true,
    addAttributes () {
        return {
            "data-id": {
                default: null
            },
            src: {
                default: "",
                parseHTML: (element)=>element.getAttribute("src"),
                renderHTML: (attributes)=>({
                        src: attributes.src
                    })
            },
            poster: {
                default: "",
                parseHTML: (element)=>element.getAttribute("poster"),
                renderHTML: (attributes)=>({
                        poster: attributes.poster
                    })
            },
            playlistUrl: {
                default: "",
                parseHTML: (element)=>element.getAttribute("data-playlist-url"),
                renderHTML: (attributes)=>({
                        "data-playlist-url": attributes.playlistUrl
                    })
            },
            width: {
                default: "100%",
                parseHTML: (element)=>element.getAttribute("data-width"),
                renderHTML: (attributes)=>({
                        "data-width": attributes.width
                    })
            },
            align: {
                default: "center",
                parseHTML: (element)=>element.getAttribute("data-align"),
                renderHTML: (attributes)=>({
                        "data-align": attributes.align
                    })
            },
            alt: {
                default: undefined,
                parseHTML: (element)=>element.getAttribute("alt"),
                renderHTML: (attributes)=>({
                        alt: attributes.alt
                    })
            },
            caption: {
                default: true,
                parseHTML: (element)=>element.getAttribute("data-caption") === "true",
                renderHTML: (attributes)=>({
                        "data-caption": attributes.caption
                    })
            }
        };
    },
    parseHTML () {
        return [
            {
                tag: this.options.allowBase64 ? "div[src]" : 'div[src]:not([src^="data:"])'
            }
        ];
    },
    renderHTML ({ HTMLAttributes }) {
        return [
            "div",
            mergeAttributes(this.options.HTMLAttributes, HTMLAttributes)
        ];
    }
});

//# sourceMappingURL=VideoBlockServerside.js.map