'use client';
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { EditorContent } from '@tiptap/react';
import { useEffect, useMemo, useRef } from 'react';
import i18n from 'i18next';
import { EditorContext } from '../../context/EditorContext.js';
import { IframeMenu } from '../../extensions/Iframe/menus/index.js';
import ImageBlockMenu from '../../extensions/ImageBlock/components/ImageBlockMenu.js';
import { InsideLinksMenu } from '../../extensions/InsideLinks/menus/index.js';
import { ColumnsMenu } from '../../extensions/MultiColumn/menus/ColumnsMenu.js';
import { SocialMediaMenu } from '../../extensions/SocialMedia/menus/index.js';
import VideoBlockMenu from '../../extensions/VideoBlock/components/VideoBlockMenu.js';
import { useBlockEditor } from '../../hooks/useBlockEditor.js';
import { ContentItemMenu } from '../menus/ContentItemMenu/ContentItemMenu.js';
import { TextMenu } from '../menus/TextMenu/TextMenu.js';
import { LinkMenu } from '../menus/index.js';
import i18next from 'i18next';
import ILinkPreviewMenu from '../../extensions/LinkPreview/menus/linkPreviewMenu.js';
const DEFAULT_LANG = 'en';
export const BlockEditor = ({ handleChange, content, openAssetHQHandler, additionalContext, isEditable = true, autoFocus = true, dir, fetchSiteMetadata })=>{
    const menuContainerRef = useRef(null);
    const editorRef = useRef(null);
    const { editor, users, characterCount, leftSidebar } = useBlockEditor({
        content: content,
        handleChange: handleChange,
        openAssetHQHandler: openAssetHQHandler,
        additionalContext: additionalContext,
        autoFocus,
        isEditable
    });
    const displayedUsers = users.slice(0, 3);
    const providerValue = useMemo(()=>{
        return {};
    }, []);
    useEffect(()=>{
        if (!additionalContext) {
            i18n.init({
                fallbackLng: DEFAULT_LANG,
                lng: DEFAULT_LANG,
                returnEmptyString: true,
                resources: {}
            });
            return;
        }
        if (additionalContext.language && additionalContext.translations) {
            i18n.init({
                fallbackLng: additionalContext.language,
                lng: additionalContext.language,
                returnEmptyString: true,
                resources: {
                    [additionalContext.language]: {
                        translation: additionalContext.translations
                    }
                }
            });
            return;
        }
        if (additionalContext.language) {
            i18n.init({
                fallbackLng: additionalContext?.language,
                lng: additionalContext?.language,
                returnEmptyString: true,
                resources: {}
            });
        }
    }, [
        additionalContext
    ]);
    return editor && /*#__PURE__*/ _jsx(EditorContext.Provider, {
        value: providerValue,
        children: /*#__PURE__*/ _jsx("div", {
            className: "flex h-full overflow-visible",
            ref: menuContainerRef,
            dir: i18next.dir(),
            children: /*#__PURE__*/ _jsxs("div", {
                className: "relative flex flex-col flex-1 h-full  justify-center items-center ",
                children: [
                    /*#__PURE__*/ _jsx(EditorContent, {
                        dir: i18next.dir(),
                        editor: editor,
                        ref: editorRef,
                        className: "flex-1 overflow-y-visible w-full h-full outline-none outline-offset-0",
                        style: {
                            outline: 'none'
                        }
                    }),
                    isEditable && /*#__PURE__*/ _jsxs(_Fragment, {
                        children: [
                            /*#__PURE__*/ _jsx(ContentItemMenu, {
                                editor: editor
                            }),
                            /*#__PURE__*/ _jsx(LinkMenu, {
                                editor: editor,
                                appendTo: menuContainerRef
                            }),
                            /*#__PURE__*/ _jsx(TextMenu, {
                                editor: editor,
                                dir: i18next.dir()
                            }),
                            /*#__PURE__*/ _jsx(ILinkPreviewMenu, {
                                editor: editor,
                                appendTo: menuContainerRef,
                                fetchSiteMetadata: fetchSiteMetadata
                            }),
                            /*#__PURE__*/ _jsx(IframeMenu, {
                                editor: editor,
                                appendTo: menuContainerRef
                            }),
                            /*#__PURE__*/ _jsx(SocialMediaMenu, {
                                editor: editor,
                                appendTo: menuContainerRef
                            }),
                            /*#__PURE__*/ _jsx(InsideLinksMenu, {
                                editor: editor,
                                appendTo: menuContainerRef
                            }),
                            /*#__PURE__*/ _jsx(ColumnsMenu, {
                                editor: editor,
                                appendTo: menuContainerRef
                            }),
                            /*#__PURE__*/ _jsx(ImageBlockMenu, {
                                editor: editor,
                                appendTo: menuContainerRef
                            }),
                            /*#__PURE__*/ _jsx(VideoBlockMenu, {
                                editor: editor,
                                appendTo: menuContainerRef
                            })
                        ]
                    })
                ]
            })
        })
    });
};
export default BlockEditor;

//# sourceMappingURL=BlockEditor.js.map