"use client";
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { EditorContent, useEditor } from "@tiptap/react";
import i18n from "i18next";
import { useEffect, useMemo, useRef } from "react";
import { EditorContext } from "../../context/EditorContext.js";
import i18next from "i18next";
import Text from '@tiptap/extension-text';
import Highlight from '@tiptap/extension-highlight';
import { AICommand, Paragraph } from "../../extensions/index.js";
import OneLiner from "./components/OneLiner.js";
import { AITextMenu } from "../menus/TextMenu/AITextMenu.js";
const DEFAULT_LANG = "en";
export const OneLineEditor = ({ handleChange, content, additionalContext, isEditable = true, autoFocus = true, dir })=>{
    const menuContainerRef = useRef(null);
    const editorRef = useRef(null);
    const editor = useEditor({
        content: content?.json ?? content ?? {},
        immediatelyRender: false,
        autofocus: autoFocus ?? true,
        editable: isEditable ?? true,
        onCreate: ({ editor })=>({
            }),
        extensions: [
            OneLiner,
            Text,
            Paragraph,
            AICommand,
            Highlight
        ],
        editorProps: {
            attributes: {
                languages: i18next.language,
                autocomplete: "off",
                autocorrect: "off",
                autocapitalize: "off",
                class: "min-h-full"
            }
        },
        onUpdate: ({ editor })=>{
            handleChange(editor?.getJSON() ?? {});
        }
    }, []);
    const providerValue = useMemo(()=>{
        return {};
    }, []);
    useEffect(()=>{
        if (!additionalContext) {
            i18n.init({
                fallbackLng: DEFAULT_LANG,
                lng: DEFAULT_LANG,
                returnEmptyString: true,
                resources: {}
            });
            return;
        }
        if (additionalContext.language && additionalContext.translations) {
            i18n.init({
                fallbackLng: additionalContext.language,
                lng: additionalContext.language,
                returnEmptyString: true,
                resources: {
                    [additionalContext.language]: {
                        translation: additionalContext.translations
                    }
                }
            });
            return;
        }
        if (additionalContext.language) {
            i18n.init({
                fallbackLng: additionalContext?.language,
                lng: additionalContext?.language,
                returnEmptyString: true,
                resources: {}
            });
        }
    }, []);
    return editor && /*#__PURE__*/ _jsx(EditorContext.Provider, {
        value: providerValue,
        children: /*#__PURE__*/ _jsx("div", {
            className: "flex h-full overflow-visible",
            ref: menuContainerRef,
            dir: i18next.dir(),
            children: /*#__PURE__*/ _jsxs("div", {
                className: "one-liner relative flex flex-col flex-1 h-full  justify-center items-center ",
                children: [
                    /*#__PURE__*/ _jsx(EditorContent, {
                        dir: i18next.dir(),
                        editor: editor,
                        ref: editorRef,
                        className: "flex-1 overflow-y-visible w-full h-full outline-none outline-offset-0",
                        style: {
                            outline: "none"
                        }
                    }),
                    isEditable && /*#__PURE__*/ _jsx(_Fragment, {
                        children: /*#__PURE__*/ _jsx(AITextMenu, {
                            editor: editor,
                            dir: i18next.dir()
                        })
                    })
                ]
            })
        })
    });
};
export default OneLineEditor;

//# sourceMappingURL=OneLineEditor.js.map