"use client";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { DragHandle } from "@tiptap-pro/extension-drag-handle-react";
import { Icon } from "../../ui/Icon.js";
import { Toolbar } from "../../ui/Toolbar.js";
import * as Popover from "@radix-ui/react-popover";
import { Clipboard, Copy, GripVertical, Plus, RemoveFormatting, Trash2 } from "lucide-react";
import { useEffect, useState } from "react";
import { DropdownButton } from "../../ui/Dropdown/Dropdown.js";
import { Surface } from "../../ui/Surface.js";
import useContentItemActions from "./hooks/useContentItemActions.js";
import { useData } from "./hooks/useData.js";
import i18next from "i18next";
export const ContentItemMenu = ({ editor })=>{
    const [menuOpen, setMenuOpen] = useState(false);
    const [tippyOptions, setTippyOptions] = useState();
    const data = useData();
    const actions = useContentItemActions(editor, data.currentNode, data.currentNodePos);
    useEffect(()=>{
        if (menuOpen) {
            editor.commands.setMeta("lockDragHandle", true);
        } else {
            editor.commands.setMeta("lockDragHandle", false);
        }
    }, [
        editor,
        menuOpen
    ]);
    return /*#__PURE__*/ _jsx(DragHandle, {
        pluginKey: "ContentItemMenu",
        editor: editor,
        onNodeChange: data.handleNodeChange,
        tippyOptions: {
            placement: "left",
            offset: [
                -12,
                2
            ],
            zIndex: 99
        },
        children: /*#__PURE__*/ _jsxs("div", {
            className: "flex items-center gap-0.5",
            children: [
                /*#__PURE__*/ _jsx(Toolbar.Button, {
                    type: "button",
                    onClick: actions.handleAdd,
                    children: /*#__PURE__*/ _jsx(Icon, {
                        icon: Plus
                    })
                }),
                /*#__PURE__*/ _jsxs(Popover.Root, {
                    open: menuOpen,
                    onOpenChange: setMenuOpen,
                    children: [
                        /*#__PURE__*/ _jsx(Popover.Trigger, {
                            asChild: true,
                            children: /*#__PURE__*/ _jsx(Toolbar.Button, {
                                type: "button",
                                children: /*#__PURE__*/ _jsx(Icon, {
                                    icon: GripVertical
                                })
                            })
                        }),
                        /*#__PURE__*/ _jsx(Popover.Content, {
                            side: "bottom",
                            align: "start",
                            sideOffset: 8,
                            children: /*#__PURE__*/ _jsxs(Surface, {
                                className: "p-2 flex flex-col min-w-[16rem]",
                                children: [
                                    /*#__PURE__*/ _jsx(Popover.Close, {
                                        children: /*#__PURE__*/ _jsxs(DropdownButton, {
                                            onClick: actions.resetTextFormatting,
                                            children: [
                                                /*#__PURE__*/ _jsx(Icon, {
                                                    icon: RemoveFormatting
                                                }),
                                                i18next.t("clearFormatting") || "Clear formatting"
                                            ]
                                        })
                                    }),
                                    /*#__PURE__*/ _jsx(Popover.Close, {
                                        children: /*#__PURE__*/ _jsxs(DropdownButton, {
                                            onClick: actions.copyNodeToClipboard,
                                            children: [
                                                /*#__PURE__*/ _jsx(Icon, {
                                                    icon: Clipboard
                                                }),
                                                i18next.t("copyToClipboard") || "Copy to clipboard"
                                            ]
                                        })
                                    }),
                                    /*#__PURE__*/ _jsx(Popover.Close, {
                                        children: /*#__PURE__*/ _jsxs(DropdownButton, {
                                            onClick: actions.duplicateNode,
                                            children: [
                                                /*#__PURE__*/ _jsx(Icon, {
                                                    icon: Copy
                                                }),
                                                i18next.t("duplicate") || "Duplicate"
                                            ]
                                        })
                                    }),
                                    /*#__PURE__*/ _jsx(Toolbar.Divider, {
                                        horizontal: true
                                    }),
                                    /*#__PURE__*/ _jsx(Popover.Close, {
                                        children: /*#__PURE__*/ _jsxs(DropdownButton, {
                                            onClick: actions.deleteNode,
                                            className: "text-red-500 bg-red-500 dark:text-red-500 hover:bg-red-500 dark:hover:text-red-500 dark:hover:bg-red-500 bg-opacity-10 hover:bg-opacity-20 dark:hover:bg-opacity-20",
                                            children: [
                                                /*#__PURE__*/ _jsx(Icon, {
                                                    icon: Trash2
                                                }),
                                                i18next.t("delete") || "Delete"
                                            ]
                                        })
                                    })
                                ]
                            })
                        })
                    ]
                })
            ]
        })
    });
};

//# sourceMappingURL=ContentItemMenu.js.map