import { useCallback } from 'react';
const useContentItemActions = (editor, currentNode, currentNodePos)=>{
    const resetTextFormatting = useCallback(()=>{
        const chain = editor.chain();
        chain.setNodeSelection(currentNodePos).unsetAllMarks();
        if (currentNode?.type.name !== 'paragraph') {
            chain.setParagraph();
        }
        chain.run();
    }, [
        editor,
        currentNodePos,
        currentNode?.type.name
    ]);
    const duplicateNode = useCallback(()=>{
        editor.commands.setNodeSelection(currentNodePos);
        const { $anchor } = editor.state.selection;
        const selectedNode = $anchor.node(1) || editor.state.selection.node;
        editor.chain().setMeta('hideDragHandle', true).insertContentAt(currentNodePos + (currentNode?.nodeSize || 0), selectedNode.toJSON()).run();
    }, [
        editor,
        currentNodePos,
        currentNode?.nodeSize
    ]);
    const copyNodeToClipboard = useCallback(()=>{
        editor.chain().setMeta('hideDragHandle', true).setNodeSelection(currentNodePos).run();
        document.execCommand('copy');
    }, [
        editor,
        currentNodePos
    ]);
    const deleteNode = useCallback(()=>{
        editor.chain().setMeta('hideDragHandle', true).setNodeSelection(currentNodePos).deleteSelection().run();
    }, [
        editor,
        currentNodePos
    ]);
    const handleAdd = useCallback(()=>{
        if (currentNodePos !== -1) {
            const currentNodeSize = currentNode?.nodeSize || 0;
            const insertPos = currentNodePos + currentNodeSize;
            const currentNodeIsEmptyParagraph = currentNode?.type.name === 'paragraph' && currentNode?.content?.size === 0;
            const focusPos = currentNodeIsEmptyParagraph ? currentNodePos + 2 : insertPos + 2;
            editor.chain().command(({ dispatch, tr, state })=>{
                if (dispatch) {
                    if (currentNodeIsEmptyParagraph) {
                        tr.insertText('/', currentNodePos, currentNodePos + 1);
                    } else {
                        tr.insert(insertPos, state.schema.nodes.paragraph.create(null, [
                            state.schema.text('/')
                        ]));
                    }
                    return dispatch(tr);
                }
                return true;
            }).focus(focusPos).run();
        }
    }, [
        currentNode,
        currentNodePos,
        editor
    ]);
    return {
        resetTextFormatting,
        duplicateNode,
        copyNodeToClipboard,
        deleteNode,
        handleAdd
    };
};
export default useContentItemActions;

//# sourceMappingURL=useContentItemActions.js.map