import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { BubbleMenu as BaseBubbleMenu } from "@tiptap/react";
import { useCallback, useState } from "react";
import { Instagram, Twitter, Youtube } from "lucide-react";
import { LinkEditorPanel, LinkPreviewPanel } from "../../panels/index.js";
import { Surface } from "../../ui/Surface.js";
import { Toolbar } from "../../ui/Toolbar.js";
export const LinkMenu = ({ editor, appendTo })=>{
    const [showEdit, setShowEdit] = useState(false);
    const shouldShow = useCallback(()=>{
        const isActive = editor.isActive("link");
        return isActive;
    }, [
        editor
    ]);
    const shouldShowSocialMedia = useCallback(()=>{
        const { href: link, target } = editor.getAttributes("link");
        const isActive = editor.isActive("link");
        return isActive && checkIfMatchesSocialMedia(link);
    }, [
        editor
    ]);
    const { href: link, target } = editor.getAttributes("link");
    const handleEdit = useCallback(()=>{
        setShowEdit(true);
    }, []);
    const onSetLink = useCallback((url, openInNewTab)=>{
        editor.chain().focus().extendMarkRange("link").setLink({
            href: url,
            target: openInNewTab ? "_blank" : ""
        }).run();
        setShowEdit(false);
    }, [
        editor
    ]);
    const onUnsetLink = useCallback(()=>{
        editor.chain().focus().extendMarkRange("link").unsetLink().run();
        setShowEdit(false);
        return null;
    }, [
        editor
    ]);
    const onShowEdit = useCallback(()=>{
        setShowEdit(true);
    }, []);
    const onHideEdit = useCallback(()=>{
        setShowEdit(false);
    }, []);
    return /*#__PURE__*/ _jsxs(_Fragment, {
        children: [
            /*#__PURE__*/ _jsx(BaseBubbleMenu, {
                editor: editor,
                pluginKey: "textMenu",
                shouldShow: shouldShow,
                updateDelay: 0,
                tippyOptions: {
                    popperOptions: {
                        modifiers: [
                            {
                                name: "flip",
                                enabled: false
                            }
                        ]
                    },
                    appendTo: ()=>{
                        return appendTo?.current;
                    },
                    onHidden: ()=>{
                        setShowEdit(false);
                    }
                },
                children: showEdit ? /*#__PURE__*/ _jsx(LinkEditorPanel, {
                    initialUrl: link,
                    initialOpenInNewTab: target === "_blank",
                    onSetLink: onSetLink
                }) : /*#__PURE__*/ _jsx(LinkPreviewPanel, {
                    url: link,
                    onClear: onUnsetLink,
                    onEdit: handleEdit
                })
            }),
            /*#__PURE__*/ _jsx(BaseBubbleMenu, {
                editor: editor,
                pluginKey: "socialMediaTextMenu",
                shouldShow: shouldShowSocialMedia,
                updateDelay: 0,
                tippyOptions: {
                    popperOptions: {
                        placement: "bottom-start"
                    },
                    placement: "bottom-start",
                    appendTo: ()=>{
                        return appendTo?.current;
                    },
                    onHidden: ()=>{
                        setShowEdit(false);
                    }
                },
                children: /*#__PURE__*/ _jsx(Surface, {
                    className: "p-2 min-w-[20rem]",
                    children: checkIfMatch(link, editor)
                })
            })
        ]
    });
};
export default LinkMenu;
const checkIfMatch = (url, editor)=>{
    const twitterRegex = /^https:\/\/twitter\.com\/([a-zA-Z0-9_-]+)\/status\/(\d+)/g;
    const instagramRegex = /^https:\/\/www\.instagram\.com\/p\/([A-Za-z0-9_-]+)/g;
    const youtubeRegex = /^((?:https?:)?\/\/)?((?:www|m)\.)?((?:youtube(-nocookie)?\.com|youtu.be))(\/(?:[\w\-]+\?v=|embed\/|live\/|v\/)?)([\w\-]+)(\S+)?/g;
    if (twitterRegex.test(url)) {
        return /*#__PURE__*/ _jsxs(Toolbar.Button, {
            onClick: ()=>{
                editor.chain().selectParentNode().deleteSelection().insertTwitter(url).run();
            },
            value: "continue",
            className: "gap-2 px-4 w-full flex justify-start",
            children: [
                /*#__PURE__*/ _jsx(Twitter, {}),
                "Embed Tweet"
            ]
        });
    } else if (instagramRegex.test(url)) {
        return /*#__PURE__*/ _jsxs(Toolbar.Button, {
            onClick: ()=>{
                editor.chain().selectParentNode().deleteSelection().insertInstagram(url).run();
            },
            value: "continue",
            className: "gap-2 px-4 w-full flex justify-start",
            children: [
                /*#__PURE__*/ _jsx(Instagram, {}),
                "Embed Instagram"
            ]
        });
    } else if (youtubeRegex.test(url)) {
        return /*#__PURE__*/ _jsxs(Toolbar.Button, {
            onClick: ()=>{
                editor.chain().selectParentNode().deleteSelection().insertYoutube(url).run();
            },
            value: "continue",
            className: "gap-2 px-4 w-full flex justify-start",
            children: [
                /*#__PURE__*/ _jsx(Youtube, {}),
                "Embed Youtube"
            ]
        });
    }
    return null;
};
const checkIfMatchesSocialMedia = (url)=>{
    const twitterRegex = /^https:\/\/twitter\.com\/([a-zA-Z0-9_-]+)\/status\/(\d+)/g;
    const instagramRegex = /^https:\/\/www\.instagram\.com\/p\/([A-Za-z0-9_-]+)/g;
    const youtubeRegex = /^((?:https?:)?\/\/)?((?:www|m)\.)?((?:youtube(-nocookie)?\.com|youtu.be))(\/(?:[\w\-]+\?v=|embed\/|live\/|v\/)?)([\w\-]+)(\S+)?/g;
    if (twitterRegex.test(url)) {
        return true;
    } else if (instagramRegex.test(url)) {
        return true;
    } else if (youtubeRegex.test(url)) {
        return true;
    }
    return false;
};

//# sourceMappingURL=LinkMenu.js.map