import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import * as Popover from "@radix-ui/react-popover";
import { BubbleMenu } from "@tiptap/react";
import { AlignCenter, AlignJustify, AlignLeft, AlignRight, Bold, Italic, MoveVertical, RemoveFormatting, Sparkles, Strikethrough, Subscript, Superscript, Underline } from "lucide-react";
import { memo, useState } from "react";
import { AIEditorPanel } from "../../panels/AIEditorPanel/AIEditorPanel.js";
import { ColorPicker } from "../../panels/index.js";
import { Icon } from "../../ui/Icon.js";
import { Toolbar } from "../../ui/Toolbar.js";
import { ContentTypePicker } from "./components/ContentTypePicker.js";
import { EditLinkPopover } from "./components/EditLinkPopover.js";
// import { FontFamilyPicker } from "./components/FontFamilyPicker.js";
import { FontSizePicker } from "./components/FontSizePicker.js";
import { useTextmenuCommands } from "./hooks/useTextmenuCommands.js";
import { useTextmenuContentTypes } from "./hooks/useTextmenuContentTypes.js";
import { useTextmenuStates } from "./hooks/useTextmenuStates.js";
import i18next from "i18next";
// We memorize the button so each button is not rerendered
// on every editor state change
const MemoButton = /*#__PURE__*/ memo(Toolbar.Button);
const MemoColorPicker = /*#__PURE__*/ memo(ColorPicker);
// const MemoFontFamilyPicker = memo(FontFamilyPicker);
const MemoFontSizePicker = /*#__PURE__*/ memo(FontSizePicker);
const MemoContentTypePicker = /*#__PURE__*/ memo(ContentTypePicker);
export const TextMenu = ({ editor, dir })=>{
    const commands = useTextmenuCommands(editor);
    const states = useTextmenuStates(editor);
    const blockOptions = useTextmenuContentTypes(editor);
    const [openAi, setOpenAi] = useState(false);
    return /*#__PURE__*/ _jsx(BubbleMenu, {
        tippyOptions: {
            placement: "auto",
            popperOptions: {
                placement: "auto"
            },
            onHide: ()=>{
                setOpenAi(false);
            }
        },
        editor: editor,
        pluginKey: "textMenu",
        shouldShow: states.shouldShow,
        updateDelay: 100,
        children: openAi ? /*#__PURE__*/ _jsx(AIEditorPanel, {
            editor: editor,
            onOpenChange: (value)=>{
                setOpenAi(value);
            }
        }) : /*#__PURE__*/ _jsxs(Toolbar.Wrapper, {
            children: [
                /*#__PURE__*/ _jsxs(Toolbar.Button, {
                    className: "text-purple-500 hover:text-purple-600 active:text-purple-600 dark:text-purple-400 dark:hover:text-purple-300 dark:active:text-purple-400",
                    activeClassname: "text-purple-600 hover:text-purple-600 dark:text-purple-400 dark:hover:text-purple-200",
                    onClick: ()=>setOpenAi(true),
                    children: [
                        /*#__PURE__*/ _jsx(Icon, {
                            icon: Sparkles,
                            className: "mr-1"
                        }),
                        i18next.t("aiTools") || "AI Tools",
                        /*#__PURE__*/ _jsx("span", {
                            className: "text-xs ml-1 px-2 py-1 bg-purple-100 text-purple-700 rounded-full dark:bg-purple-700 dark:text-purple-100 align-baseline",
                            children: "Beta"
                        })
                    ]
                }),
                /*#__PURE__*/ _jsx(Toolbar.Divider, {}),
                /*#__PURE__*/ _jsx(MemoContentTypePicker, {
                    options: blockOptions
                }),
                /*#__PURE__*/ _jsx(Toolbar.Divider, {}),
                /*#__PURE__*/ _jsx(MemoButton, {
                    type: "button",
                    tooltip: i18next.t("boldText") || "Bold",
                    tooltipShortcut: [
                        "Mod",
                        "B"
                    ],
                    onClick: commands.onBold,
                    active: states.isBold,
                    children: /*#__PURE__*/ _jsx(Icon, {
                        icon: Bold
                    })
                }),
                /*#__PURE__*/ _jsx(MemoButton, {
                    type: "button",
                    tooltip: i18next.t("italicText") || "Italic",
                    tooltipShortcut: [
                        "Mod",
                        "I"
                    ],
                    onClick: commands.onItalic,
                    active: states.isItalic,
                    children: /*#__PURE__*/ _jsx(Icon, {
                        icon: Italic
                    })
                }),
                /*#__PURE__*/ _jsx(MemoButton, {
                    type: "button",
                    tooltip: i18next.t("underlineText") || "Underline",
                    tooltipShortcut: [
                        "Mod",
                        "U"
                    ],
                    onClick: commands.onUnderline,
                    active: states.isUnderline,
                    children: /*#__PURE__*/ _jsx(Icon, {
                        icon: Underline
                    })
                }),
                /*#__PURE__*/ _jsx(EditLinkPopover, {
                    onSetLink: commands.onLink
                }),
                /*#__PURE__*/ _jsxs(Popover.Root, {
                    children: [
                        /*#__PURE__*/ _jsx(Popover.Trigger, {
                            asChild: true,
                            children: /*#__PURE__*/ _jsx(MemoButton, {
                                type: "button",
                                tooltip: i18next.t("moreOptions", "More options"),
                                children: /*#__PURE__*/ _jsx(Icon, {
                                    icon: MoveVertical
                                })
                            })
                        }),
                        /*#__PURE__*/ _jsx(Popover.Content, {
                            side: "top",
                            asChild: true,
                            children: /*#__PURE__*/ _jsxs(Toolbar.Wrapper, {
                                children: [
                                    /*#__PURE__*/ _jsx(MemoButton, {
                                        type: "button",
                                        tooltip: i18next.t("subscript", "Subscript"),
                                        tooltipShortcut: [
                                            "Mod",
                                            "."
                                        ],
                                        onClick: commands.onSubscript,
                                        active: states.isSubscript,
                                        children: /*#__PURE__*/ _jsx(Icon, {
                                            icon: Subscript
                                        })
                                    }),
                                    /*#__PURE__*/ _jsx(MemoButton, {
                                        type: "button",
                                        tooltip: i18next.t("superscript", "Superscript"),
                                        tooltipShortcut: [
                                            "Mod",
                                            ","
                                        ],
                                        onClick: commands.onSuperscript,
                                        active: states.isSuperscript,
                                        children: /*#__PURE__*/ _jsx(Icon, {
                                            icon: Superscript
                                        })
                                    }),
                                    /*#__PURE__*/ _jsx(Toolbar.Divider, {}),
                                    /*#__PURE__*/ _jsx(MemoButton, {
                                        type: "button",
                                        tooltip: i18next.t("alignLeft") || "Align left",
                                        tooltipShortcut: [
                                            "Shift",
                                            "Mod",
                                            "L"
                                        ],
                                        onClick: commands.onAlignLeft,
                                        active: states.isAlignLeft,
                                        children: /*#__PURE__*/ _jsx(Icon, {
                                            icon: AlignLeft
                                        })
                                    }),
                                    /*#__PURE__*/ _jsx(MemoButton, {
                                        type: "button",
                                        tooltip: i18next.t("alignCenter") || "Align center",
                                        tooltipShortcut: [
                                            "Shift",
                                            "Mod",
                                            "E"
                                        ],
                                        onClick: commands.onAlignCenter,
                                        active: states.isAlignCenter,
                                        children: /*#__PURE__*/ _jsx(Icon, {
                                            icon: AlignCenter
                                        })
                                    }),
                                    /*#__PURE__*/ _jsx(MemoButton, {
                                        type: "button",
                                        tooltip: i18next.t("alignRight", "Align right"),
                                        tooltipShortcut: [
                                            "Shift",
                                            "Mod",
                                            "R"
                                        ],
                                        onClick: commands.onAlignRight,
                                        active: states.isAlignRight,
                                        children: /*#__PURE__*/ _jsx(Icon, {
                                            icon: AlignRight
                                        })
                                    }),
                                    /*#__PURE__*/ _jsx(MemoButton, {
                                        type: "button",
                                        tooltip: i18next.t("alignJustify") || "Justify",
                                        tooltipShortcut: [
                                            "Shift",
                                            "Mod",
                                            "J"
                                        ],
                                        onClick: commands.onAlignJustify,
                                        active: states.isAlignJustify,
                                        children: /*#__PURE__*/ _jsx(Icon, {
                                            icon: AlignJustify
                                        })
                                    }),
                                    /*#__PURE__*/ _jsx(MemoButton, {
                                        type: "button",
                                        tooltip: i18next.t("strikethrough", "Strikethrough"),
                                        tooltipShortcut: [
                                            "Mod",
                                            "Shift",
                                            "S"
                                        ],
                                        onClick: commands.onStrike,
                                        active: states.isStrike,
                                        children: /*#__PURE__*/ _jsx(Icon, {
                                            icon: Strikethrough
                                        })
                                    }),
                                    /*#__PURE__*/ _jsx(MemoButton, {
                                        type: "button",
                                        tooltip: i18next.t("clearFormatting") || "Clear Formatting",
                                        onClick: commands.onClearFormatting,
                                        children: /*#__PURE__*/ _jsx(Icon, {
                                            icon: RemoveFormatting
                                        })
                                    })
                                ]
                            })
                        })
                    ]
                })
            ]
        })
    });
};

//# sourceMappingURL=TextMenu.js.map