import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import * as Dropdown from "@radix-ui/react-dropdown-menu";
import { ChevronDown } from "lucide-react";
import { useCallback } from "react";
import { DropdownButton, DropdownCategoryTitle } from "../../../ui/Dropdown/Dropdown.js";
import { Icon } from "../../../ui/Icon.js";
import { Surface } from "../../../ui/Surface.js";
import { Toolbar } from "../../../ui/Toolbar.js";
const FONT_FAMILY_GROUPS = [
    {
        label: "Sans Serif",
        options: [
            {
                label: "Inter",
                value: ""
            },
            {
                label: "Arial",
                value: "Arial"
            },
            {
                label: "Helvetica",
                value: "Helvetica"
            }
        ]
    },
    {
        label: "Serif",
        options: [
            {
                label: "Times New Roman",
                value: "Times"
            },
            {
                label: "Garamond",
                value: "Garamond"
            },
            {
                label: "Georgia",
                value: "Georgia"
            }
        ]
    },
    {
        label: "Monospace",
        options: [
            {
                label: "Courier",
                value: "Courier"
            },
            {
                label: "Courier New",
                value: "Courier New"
            }
        ]
    }
];
const FONT_FAMILIES = FONT_FAMILY_GROUPS.flatMap((group)=>[
        group.options
    ]).flat();
export const FontFamilyPicker = ({ onChange, value })=>{
    const currentValue = FONT_FAMILIES.find((size)=>size.value === value);
    const currentFontLabel = currentValue?.label.split(" ")[0] || "Inter";
    const selectFont = useCallback((font)=>()=>onChange(font), [
        onChange
    ]);
    return /*#__PURE__*/ _jsxs(Dropdown.Root, {
        children: [
            /*#__PURE__*/ _jsx(Dropdown.Trigger, {
                asChild: true,
                children: /*#__PURE__*/ _jsxs(Toolbar.Button, {
                    type: "button",
                    active: !!currentValue?.value,
                    children: [
                        currentFontLabel,
                        /*#__PURE__*/ _jsx(Icon, {
                            icon: ChevronDown,
                            className: "w-2 h-2"
                        })
                    ]
                })
            }),
            /*#__PURE__*/ _jsx(Dropdown.Content, {
                asChild: true,
                children: /*#__PURE__*/ _jsx(Surface, {
                    className: "flex flex-col gap-1 px-2 py-4",
                    children: FONT_FAMILY_GROUPS.map((group)=>/*#__PURE__*/ _jsxs("div", {
                            className: "mt-2.5 first:mt-0 gap-0.5 flex flex-col",
                            children: [
                                /*#__PURE__*/ _jsx(DropdownCategoryTitle, {
                                    children: group.label
                                }),
                                group.options.map((font)=>/*#__PURE__*/ _jsx(DropdownButton, {
                                        isActive: value === font.value,
                                        onClick: selectFont(font.value),
                                        children: /*#__PURE__*/ _jsx("span", {
                                            style: {
                                                fontFamily: font.value
                                            },
                                            children: font.label
                                        })
                                    }, `${font.label}_${font.value}`))
                            ]
                        }, group.label))
                })
            })
        ]
    });
};

//# sourceMappingURL=FontFamilyPicker.js.map