import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import * as Popover from '@radix-ui/react-popover';
import i18next from 'i18next';
import { ArrowDownWideNarrow, BookText, CheckCheck, ChevronDown, Languages, RefreshCcwDot, StepForward, WrapText } from 'lucide-react';
import { languages } from '../../../../lib/constants.js';
import { getPrevText } from '../../../../lib/utils/index.js';
import { DropdownCategoryTitle } from '../../../ui/Dropdown/Dropdown.js';
import { Icon } from '../../../ui/Icon.js';
import { Surface } from '../../../ui/Surface.js';
import { Toolbar } from '../../../ui/Toolbar.js';
import { useMemo } from 'react';
import { extractMarkdown } from '../../../../lib/extract.js';
const options = [
    // {
    //   value: 'translate',
    //   label: 'Translate text',
    //   icon: WrapText,
    // },
    {
        value: 'improve',
        label: 'Improve writing',
        icon: RefreshCcwDot
    },
    {
        value: 'fix',
        label: 'Fix grammar',
        icon: CheckCheck
    },
    {
        value: 'rewrite_with_guidelines',
        label: 'Rewrite per Editorial Guidelines',
        icon: BookText
    },
    {
        value: 'rewrite',
        label: 'Rewrite into Axios',
        icon: WrapText
    },
    {
        value: 'summarize',
        label: 'Summarize text',
        icon: WrapText
    },
    {
        value: 'shorter',
        label: 'Make shorter',
        icon: ArrowDownWideNarrow
    },
    {
        value: 'longer',
        label: 'Make longer',
        icon: WrapText
    }
];
const AISelectorCommands = ({ messages, onSelect, editor })=>{
    const editorSelection = editor?.state?.selection?.content?.()?.content?.toJSON();
    const sortedLanguages = useMemo(()=>{
        const editorLanguage = editor.storage?.aiCommand?.language;
        return languages.sort((a, b)=>{
            if (editorLanguage?.includes(a.value)) return -1;
            if (editorLanguage?.includes(b.value)) return 1;
            return 0;
        });
    }, [
        languages,
        editor.storage?.aiCommand?.language
    ]);
    return /*#__PURE__*/ _jsxs(_Fragment, {
        children: [
            /*#__PURE__*/ _jsx(DropdownCategoryTitle, {
                children: "Edit or review selection"
            }),
            editorSelection && /*#__PURE__*/ _jsxs(Popover.Root, {
                children: [
                    /*#__PURE__*/ _jsx(Popover.Trigger, {
                        asChild: true,
                        children: /*#__PURE__*/ _jsxs(Toolbar.Button, {
                            className: "gap-2 px-4 w-full flex justify-start ",
                            type: "button",
                            // active={!!states.currentHighlight}
                            tooltip: i18next.t('highlightText') || 'Highlight text',
                            children: [
                                /*#__PURE__*/ _jsx(Icon, {
                                    icon: Languages,
                                    className: "h-4 w-4 text-blue-500"
                                }),
                                "Translate text",
                                /*#__PURE__*/ _jsx("span", {
                                    className: "text-xs ml-1 px-2 py-0.5 bg-blue-100 text-blue-700 rounded-full dark:bg-blue-700 dark:text-blue-100 align-baseline",
                                    children: "Beta"
                                }),
                                /*#__PURE__*/ _jsx(Icon, {
                                    icon: ChevronDown,
                                    className: "h-4 w-4 text-blue-500"
                                })
                            ]
                        })
                    }),
                    /*#__PURE__*/ _jsx(Popover.Content, {
                        side: "right",
                        align: "start",
                        sideOffset: 8,
                        asChild: true,
                        children: /*#__PURE__*/ _jsxs(Surface, {
                            className: "flex flex-col min-w-[15rem] p-2 max-h-[20rem] overflow-auto",
                            children: [
                                /*#__PURE__*/ _jsx(DropdownCategoryTitle, {
                                    children: "Languages"
                                }),
                                sortedLanguages.map((lang)=>/*#__PURE__*/ _jsx(Toolbar.Button, {
                                        onClick: ()=>{
                                            const editorSelection = editor.state.selection.content().content.toJSON();
                                            onSelect('', {
                                                option: 'translate',
                                                language: lang.value,
                                                selection: editorSelection
                                            });
                                        },
                                        className: "gap-2 px-4 w-full flex justify-start ",
                                        children: lang.label
                                    }, lang.value))
                            ]
                        })
                    })
                ]
            }),
            options.map((option)=>/*#__PURE__*/ _jsxs(Toolbar.Button, {
                    // onSelect={(value) => {
                    //   const slice = editor.state.selection.content()
                    //   const text = editor?.storage?.markdown?.serializer.serialize(slice.content)
                    //   onSelect(text, option.value)
                    // }}
                    onClick: ()=>{
                        const { from, to, empty } = editor.state.selection;
                        const editorSelection = editor.state.selection.content().content.toJSON();
                        const content = messages ? extractMarkdown(messages) ?? '' : editor.state.doc.textBetween(from, to, ' ');
                        onSelect(content, {
                            option: option.value,
                            language: editor?.storage?.aiCommand?.language
                        });
                    },
                    className: " gap-2 px-4 w-full flex justify-start",
                    value: option.value,
                    children: [
                        /*#__PURE__*/ _jsx(option.icon, {
                            className: "h-4 w-4 text-blue-500"
                        }),
                        option.label,
                        /*#__PURE__*/ _jsx("span", {
                            className: "text-xs ml-1 px-2 py-0.5 bg-blue-100 text-blue-700 rounded-full dark:bg-blue-700 dark:text-blue-100 align-baseline",
                            children: "Beta"
                        })
                    ]
                }, option.value)),
            /*#__PURE__*/ _jsx(Toolbar.Divider, {
                horizontal: true
            }),
            /*#__PURE__*/ _jsx(DropdownCategoryTitle, {
                children: "Use AI to do more"
            }),
            /*#__PURE__*/ _jsxs(Toolbar.Button, {
                onClick: ()=>{
                    const editorSelection = editor.state.selection.content().content.toJSON();
                    const text = messages ? extractMarkdown(messages) ?? '' : getPrevText(editor, {
                        chars: 5000
                    });
                    onSelect(text, {
                        option: 'continue',
                        language: editor?.storage?.aiCommand?.language
                    });
                },
                value: "continue",
                className: "gap-2 px-4 w-full flex justify-start",
                children: [
                    /*#__PURE__*/ _jsx(StepForward, {
                        className: "h-4 w-4 text-blue-500"
                    }),
                    "Continue writing",
                    /*#__PURE__*/ _jsx("span", {
                        className: "text-xs ml-1 px-2 py-0.5 bg-blue-100 text-blue-700 rounded-full dark:bg-blue-700 dark:text-blue-100 align-baseline",
                        children: "Beta"
                    })
                ]
            })
        ]
    });
};
export default AISelectorCommands;

//# sourceMappingURL=ai-selector-commands.js.map