import { useMemo } from "react";
import { Pilcrow, Heading1, Heading2, Heading3, List } from "lucide-react";
import i18next from "i18next";
export const useTextmenuContentTypes = (editor)=>{
    const options = useMemo(()=>{
        return [
            {
                type: "category",
                label: i18next.t("hierarchy") || "Hierarchy",
                id: "hierarchy"
            },
            {
                icon: Pilcrow,
                onClick: ()=>editor.chain().focus().lift("taskItem").liftListItem("listItem").setParagraph().run(),
                id: "paragraph",
                disabled: ()=>!editor.can().setParagraph(),
                isActive: ()=>editor.isActive("paragraph") && !editor.isActive("orderedList") && !editor.isActive("bulletList") && !editor.isActive("taskList"),
                label: i18next.t("paragraph") || "Paragraph",
                type: "option"
            },
            {
                icon: Heading1,
                onClick: ()=>editor.chain().focus().lift("taskItem").liftListItem("listItem").setHeading({
                        level: 1
                    }).run(),
                id: "heading1",
                disabled: ()=>!editor.can().setHeading({
                        level: 1
                    }),
                isActive: ()=>editor.isActive("heading", {
                        level: 1
                    }),
                label: i18next.t("heading1") || "Heading 1",
                type: "option"
            },
            {
                icon: Heading2,
                onClick: ()=>editor.chain().focus().lift("taskItem").liftListItem("listItem").setHeading({
                        level: 2
                    }).run(),
                id: "heading2",
                disabled: ()=>!editor.can().setHeading({
                        level: 2
                    }),
                isActive: ()=>editor.isActive("heading", {
                        level: 2
                    }),
                label: i18next.t("heading2") || "Heading 2",
                type: "option"
            },
            {
                icon: Heading3,
                onClick: ()=>editor.chain().focus().lift("taskItem").liftListItem("listItem").setHeading({
                        level: 3
                    }).run(),
                id: "heading3",
                disabled: ()=>!editor.can().setHeading({
                        level: 3
                    }),
                isActive: ()=>editor.isActive("heading", {
                        level: 3
                    }),
                label: i18next.t("heading3") || "Heading 3",
                type: "option"
            },
            // {
            //   type: "category",
            //   label: i18next.t("lists") || "Lists",
            //   id: "lists",
            // },
            {
                icon: List,
                onClick: ()=>editor.chain().focus().toggleBulletList().run(),
                id: "bulletList",
                disabled: ()=>!editor.can().toggleBulletList(),
                isActive: ()=>editor.isActive("bulletList"),
                label: i18next.t("bulletList") || "Bullet list",
                type: "option"
            }
        ];
    // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [
        editor,
        editor.state
    ]);
    return options;
};

//# sourceMappingURL=useTextmenuContentTypes.js.map