'use client';
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { ArrowUpCircle, Sparkles } from 'lucide-react';
import React, { forwardRef, useCallback, useEffect, useImperativeHandle, useRef, useState } from 'react';
import Markdown from 'react-markdown';
import TextareaAutosize from 'react-textarea-autosize';
import { experimental_useObject as useObject } from '@ai-sdk/react';
import i18next from 'i18next';
import { TiptapSchema } from '../../../lib/tiptapSchema.js';
import AISelectorCommands from '../../menus/TextMenu/components/ai-selector-commands.js';
import CrazySpinner from '../../ui/crazy-spinner.js';
import { DropdownButton } from '../../ui/Dropdown/Dropdown.js';
import { Icon } from '../../ui/Icon.js';
import { ScrollArea } from '../../ui/scroll-area.js';
import { Surface } from '../../ui/Surface.js';
import { Toolbar } from '../../ui/Toolbar.js';
import { useExtractMarkdown } from '../AIEditorPanel/markdown.hook.js';
export const AICommandPanel = /*#__PURE__*/ forwardRef(({ editor, onOpenChange, userPrompt, items, ...restProps }, ref)=>{
    const [inputValue, setInputValue] = useState(userPrompt ?? '');
    const { view } = editor;
    const scrollContainer = useRef(null);
    const activeItem = useRef(null);
    const [selectedGroupIndex, setSelectedGroupIndex] = useState(0);
    const [selectedCommandIndex, setSelectedCommandIndex] = useState(0);
    const editorNode = view.dom;
    const boundigClient = editorNode.getBoundingClientRect();
    const inputRef = useRef(null);
    const { object, submit, isLoading } = useObject({
        api: '/api/generate',
        schema: TiptapSchema
    });
    const { markdown } = useExtractMarkdown(object);
    const hasCompletion = Boolean(object);
    const handleClick = useCallback(()=>{
        if (object) {
            submit({
                prompt: '',
                body: {
                    option: 'zap',
                    command: inputValue,
                    language: editor?.storage?.aiCommand?.language,
                    selection: object
                }
            });
            setInputValue('');
            return;
        }
        submit({
            prompt: '',
            body: {
                option: 'zap',
                command: inputValue,
                language: editor?.storage?.aiCommand?.language
            }
        });
        setInputValue('');
    }, [
        editor?.storage?.aiCommand?.language,
        inputValue,
        object,
        submit
    ]);
    useEffect(()=>{
        if (userPrompt) setInputValue(userPrompt);
    }, [
        userPrompt
    ]);
    useEffect(()=>{
        if (!!hasCompletion) {
            editor.storage.aiCommand.completion = object?.content ?? [];
        }
    }, [
        markdown,
        isLoading
    ]);
    useEffect(()=>{
        setSelectedGroupIndex(0);
        setSelectedCommandIndex(0);
    }, [
        items
    ]);
    const selectItem = useCallback((groupIndex, commandIndex)=>{
        const command = items[groupIndex].commands[commandIndex];
        setInputValue(command.action(editor));
    }, [
        items,
        editor
    ]);
    useImperativeHandle(ref, ()=>({
            onKeyDown: ({ event })=>{
                if (event.key === 'ArrowDown') {
                    if (!items.length) {
                        return false;
                    }
                    const commands = items[selectedGroupIndex].commands;
                    let newCommandIndex = selectedCommandIndex + 1;
                    let newGroupIndex = selectedGroupIndex;
                    if (commands.length - 1 < newCommandIndex) {
                        newCommandIndex = 0;
                        newGroupIndex = selectedGroupIndex + 1;
                    }
                    if (items.length - 1 < newGroupIndex) {
                        newGroupIndex = 0;
                    }
                    setSelectedCommandIndex(newCommandIndex);
                    setSelectedGroupIndex(newGroupIndex);
                    return true;
                }
                if (event.key === 'ArrowUp') {
                    if (!items.length) {
                        return false;
                    }
                    let newCommandIndex = selectedCommandIndex - 1;
                    let newGroupIndex = selectedGroupIndex;
                    if (newCommandIndex < 0) {
                        newGroupIndex = selectedGroupIndex - 1;
                        newCommandIndex = items[newGroupIndex]?.commands.length - 1 || 0;
                    }
                    if (newGroupIndex < 0) {
                        newGroupIndex = items.length - 1;
                        newCommandIndex = items[newGroupIndex].commands.length - 1;
                    }
                    setSelectedCommandIndex(newCommandIndex);
                    setSelectedGroupIndex(newGroupIndex);
                    return true;
                }
                if (event.key === 'Enter') {
                    if (!items.length || selectedGroupIndex === -1 || selectedCommandIndex === -1) {
                        return false;
                    }
                    selectItem(selectedGroupIndex, selectedCommandIndex);
                    return true;
                }
                return false;
            }
        }));
    useEffect(()=>{
        if (activeItem.current && scrollContainer.current) {
            const offsetTop = activeItem.current.offsetTop;
            const offsetHeight = activeItem.current.offsetHeight;
            scrollContainer.current.scrollTop = offsetTop - offsetHeight;
        }
    }, [
        selectedCommandIndex,
        selectedGroupIndex
    ]);
    const createCommandClickHandler = useCallback((groupIndex, commandIndex)=>{
        return ()=>{
            selectItem(groupIndex, commandIndex);
        };
    }, [
        selectItem
    ]);
    return /*#__PURE__*/ _jsxs(_Fragment, {
        children: [
            /*#__PURE__*/ _jsx(Surface, {
                className: `p-2 min-w-[20rem] flex  flex-col gap-2 w-full ${hasCompletion ? '-mt-72' : ''}`,
                style: {
                    width: boundigClient?.width
                },
                children: /*#__PURE__*/ _jsxs(_Fragment, {
                    children: [
                        markdown && /*#__PURE__*/ _jsx("div", {
                            className: "flex  w-full",
                            children: /*#__PURE__*/ _jsx(ScrollArea, {
                                className: "prose p-2 px-4 prose-sm max-h-96",
                                dir: i18next.dir(),
                                children: /*#__PURE__*/ _jsx(Markdown, {
                                    children: markdown
                                })
                            })
                        }),
                        isLoading && /*#__PURE__*/ _jsxs("div", {
                            className: "flex h-12 w-full items-center px-4 text-sm font-medium text-muted-foreground text-blue-500",
                            style: {
                                width: boundigClient?.width
                            },
                            children: [
                                /*#__PURE__*/ _jsx(Sparkles, {
                                    className: "mr-2 h-4 w-4 shrink-0  "
                                }),
                                "AI (Beta) is thinking",
                                /*#__PURE__*/ _jsx("div", {
                                    className: "ml-2 mt-1",
                                    children: /*#__PURE__*/ _jsx(CrazySpinner, {})
                                })
                            ]
                        }),
                        !isLoading && /*#__PURE__*/ _jsx(_Fragment, {
                            children: /*#__PURE__*/ _jsxs("div", {
                                className: "flex justify-between items-center ",
                                children: [
                                    /*#__PURE__*/ _jsx(Sparkles, {
                                        className: "mr-2 h-4 w-4 shrink-0 text-blue-500 "
                                    }),
                                    /*#__PURE__*/ _jsx(TextareaAutosize, {
                                        ref: inputRef,
                                        style: {
                                            resize: 'none'
                                        },
                                        className: "w-full p-2 text-black bg-white  rounded dark:bg-black dark:text-white focus:outline-none outline-none border-0 ",
                                        value: inputValue,
                                        onChange: (e)=>{
                                            editor.storage.aiCommand.userPrompt = e.target.value;
                                            setInputValue(e.target.value);
                                        },
                                        placeholder: hasCompletion ? i18next.t('tellAiPlaceholder') || 'Tell AI (Beta) what to do next' : i18next.t('askAiPlaceholder') || 'Ask AI (Beta) to edit or generate...',
                                        autoFocus: true,
                                        onKeyDown: (e)=>{
                                            if (e.key === 'Enter') handleClick();
                                        }
                                    }),
                                    /*#__PURE__*/ _jsx(Toolbar.Button, {
                                        onClick: handleClick,
                                        children: /*#__PURE__*/ _jsx(ArrowUpCircle, {})
                                    })
                                ]
                            })
                        })
                    ]
                })
            }),
            !isLoading && /*#__PURE__*/ _jsx(Surface, {
                ref: scrollContainer,
                className: "text-black max-h-[min(80vh,24rem)] overflow-auto flex-wrap mb-8 p-2",
                children: /*#__PURE__*/ _jsx("div", {
                    className: "grid grid-cols-1 gap-0.5",
                    children: hasCompletion ? /*#__PURE__*/ _jsx(AISelectorCommands, {
                        editor: editor,
                        messages: object,
                        onSelect: (value, options)=>{
                            if (options?.option === 'translate') {
                                submit({
                                    prompt: value,
                                    body: options
                                });
                            } else {
                                submit({
                                    prompt: value,
                                    body: {
                                        ...options,
                                        source: editor?.storage?.aiCommand?.language
                                    }
                                });
                            }
                        }
                    }) : items.map((group, groupIndex)=>/*#__PURE__*/ _jsxs(React.Fragment, {
                            children: [
                                /*#__PURE__*/ _jsx("div", {
                                    className: "text-neutral-500 text-[0.65rem] col-[1/-1] mx-2 mt-4 font-semibold tracking-wider select-none uppercase first:mt-0.5",
                                    children: group.title
                                }, `${group.title}`),
                                group.commands.map((command, commandIndex)=>/*#__PURE__*/ _jsxs(DropdownButton, {
                                        isActive: selectedGroupIndex === groupIndex && selectedCommandIndex === commandIndex,
                                        onClick: createCommandClickHandler(groupIndex, commandIndex),
                                        children: [
                                            /*#__PURE__*/ _jsx(Icon, {
                                                icon: command.icon,
                                                className: "mr-1"
                                            }),
                                            command.label
                                        ]
                                    }, `${command.label}`))
                            ]
                        }, `${group.title}-wrapper`))
                })
            })
        ]
    });
});

//# sourceMappingURL=AICommandPanel.js.map