'use client';
import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { ArrowRight, Sparkles } from 'lucide-react';
import { useCallback, useRef, useState } from 'react';
import TextareaAutosize from 'react-textarea-autosize';
import { experimental_useObject as useObject } from '@ai-sdk/react';
import i18next from 'i18next';
import Markdown from 'react-markdown';
import { TiptapSchema } from '../../../lib/tiptapSchema.js';
import { getPrevText } from '../../../lib/utils/index.js';
import AICompletionCommands from '../../menus/TextMenu/components/ai-completion-command.js';
import AISelectorCommands from '../../menus/TextMenu/components/ai-selector-commands.js';
import { Surface } from '../../ui/Surface.js';
import { Toolbar } from '../../ui/Toolbar.js';
import CrazySpinner from '../../ui/crazy-spinner.js';
import { ScrollArea } from '../../ui/scroll-area.js';
import { useExtractMarkdown } from './markdown.hook.js';
export const AIEditorPanel = ({ editor, onOpenChange })=>{
    const [inputValue, setInputValue] = useState('');
    const { view } = editor;
    const editorNode = view.dom;
    const boundigClient = editorNode.getBoundingClientRect();
    const inputRef = useRef(null);
    const { object, submit, isLoading } = useObject({
        api: '/api/generate',
        schema: TiptapSchema
    });
    const hasCompletion = Boolean(object);
    const handleClick = useCallback(()=>{
        if (object) {
            submit({
                prompt: object,
                body: {
                    option: 'zap',
                    command: inputValue,
                    language: editor?.storage?.aiCommand?.language
                }
            });
            setInputValue('');
            return;
        }
        const text = getPrevText(editor, {
            chars: 5000
        });
        submit({
            prompt: text,
            body: {
                option: 'zap',
                command: inputValue,
                language: editor?.storage?.aiCommand?.language
            }
        });
        setInputValue('');
    }, [
        editor?.storage?.aiCommand?.language,
        inputValue,
        object,
        submit
    ]);
    const { markdown } = useExtractMarkdown(object);
    return /*#__PURE__*/ _jsx(Surface, {
        className: `p-2 min-w-[20rem] `,
        style: {
            width: boundigClient?.width
        },
        children: /*#__PURE__*/ _jsxs(_Fragment, {
            children: [
                markdown && /*#__PURE__*/ _jsx("div", {
                    className: "flex  w-full",
                    children: /*#__PURE__*/ _jsx(ScrollArea, {
                        className: "prose p-2 px-4 prose-sm max-h-96",
                        dir: i18next.dir(),
                        children: /*#__PURE__*/ _jsx(Markdown, {
                            children: markdown
                        })
                    })
                }),
                isLoading && /*#__PURE__*/ _jsxs("div", {
                    className: "flex h-12 w-full items-center px-4 text-sm font-medium text-muted-foreground text-blue-500",
                    children: [
                        /*#__PURE__*/ _jsx(Sparkles, {
                            className: "mr-2 h-4 w-4 shrink-0  "
                        }),
                        "AI (Beta) is thinking",
                        /*#__PURE__*/ _jsx("div", {
                            className: "ml-2 mt-1",
                            children: /*#__PURE__*/ _jsx(CrazySpinner, {})
                        })
                    ]
                }),
                !isLoading && /*#__PURE__*/ _jsxs(_Fragment, {
                    children: [
                        /*#__PURE__*/ _jsxs("div", {
                            className: "flex justify-between items-center",
                            children: [
                                /*#__PURE__*/ _jsx(Sparkles, {
                                    className: "mr-2 h-4 w-4 shrink-0 text-blue-500 "
                                }),
                                /*#__PURE__*/ _jsx(TextareaAutosize, {
                                    ref: inputRef,
                                    className: "w-full p-2 text-black bg-white  rounded dark:bg-black dark:text-white focus:outline-none",
                                    value: inputValue,
                                    onChange: (e)=>{
                                        setInputValue(e.target.value);
                                    },
                                    placeholder: hasCompletion ? i18next.t('tellAiPlaceholder') || 'Tell AI (Beta) what to do next' : i18next.t('askAiPlaceholder') || 'Ask AI (Beta) to edit or generate...',
                                    autoFocus: true,
                                    onKeyDown: (e)=>{
                                        if (e.key === 'Enter') handleClick();
                                    }
                                }),
                                /*#__PURE__*/ _jsx(Toolbar.Button, {
                                    onClick: handleClick,
                                    children: /*#__PURE__*/ _jsx(ArrowRight, {})
                                })
                            ]
                        }),
                        hasCompletion ? /*#__PURE__*/ _jsx(AICompletionCommands, {
                            editor: editor,
                            onDiscard: ()=>{
                                editor?.chain()?.focus()?.run();
                                onOpenChange(false);
                            },
                            completion: object
                        }) : /*#__PURE__*/ _jsx(AISelectorCommands, {
                            messages: object,
                            editor: editor,
                            onSelect: (value, options)=>{
                                submit({
                                    prompt: value,
                                    body: options
                                });
                            }
                        })
                    ]
                })
            ]
        })
    });
};

//# sourceMappingURL=AIEditorPanel.js.map