'use client';
import { jsx as _jsx } from "react/jsx-runtime";
import { EditorContent } from '@tiptap/react';
import i18n from 'i18next';
import { useEffect, useMemo, useRef } from 'react';
import i18next from 'i18next';
import { useBlockEditor } from '../../../hooks/useBlockEditor.js';
import { EditorContext } from '../../../context/EditorContext.js';
const DEFAULT_LANG = 'en';
export const EditorPreview = ({ handleChange, content, openAssetHQHandler, additionalContext, isEditable = true, dir })=>{
    const menuContainerRef = useRef(null);
    const editorRef = useRef(null);
    const { editor, users, characterCount, leftSidebar } = useBlockEditor({
        content: content,
        handleChange: handleChange,
        openAssetHQHandler: openAssetHQHandler,
        additionalContext: additionalContext,
        isEditable,
        autoFocus: true
    });
    const displayedUsers = users.slice(0, 3);
    const providerValue = useMemo(()=>{
        return {};
    }, []);
    useEffect(()=>{
        if (!additionalContext) {
            i18n.init({
                fallbackLng: DEFAULT_LANG,
                lng: DEFAULT_LANG,
                returnEmptyString: true,
                resources: {}
            });
            return;
        }
        if (additionalContext.language && additionalContext.translations) {
            i18n.init({
                fallbackLng: additionalContext.language,
                lng: additionalContext.language,
                returnEmptyString: true,
                resources: {
                    [additionalContext.language]: {
                        translation: additionalContext.translations
                    }
                }
            });
            return;
        }
        if (additionalContext.language) {
            i18n.init({
                fallbackLng: additionalContext?.language,
                lng: additionalContext?.language,
                returnEmptyString: true,
                resources: {}
            });
        }
    }, []);
    return editor && /*#__PURE__*/ _jsx(EditorContext.Provider, {
        value: providerValue,
        children: /*#__PURE__*/ _jsx("div", {
            className: "flex h-full overflow-visible",
            ref: menuContainerRef,
            dir: i18next.dir(),
            children: /*#__PURE__*/ _jsx("div", {
                className: "relative flex flex-col flex-1 h-full  justify-center items-center ",
                children: /*#__PURE__*/ _jsx(EditorContent, {
                    dir: i18next.dir(),
                    editor: editor,
                    ref: editorRef,
                    className: "flex-1 overflow-y-visible w-full h-full outline-none outline-offset-0",
                    style: {
                        outline: 'none'
                    }
                })
            })
        })
    });
};
export default EditorPreview;

//# sourceMappingURL=EditorPreview.js.map