import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React, { useCallback, useState } from "react";
import { HexColorPicker } from "react-colorful";
import { ColorButton } from "./ColorButton.js";
import { Toolbar } from "../../ui/Toolbar.js";
import { Icon } from "../../ui/Icon.js";
import { themeColors } from "../../../lib/constants.js";
import { Undo } from "lucide-react";
import i18next from "i18next";
export const ColorPicker = ({ color, onChange, onClear })=>{
    const [colorInputValue, setColorInputValue] = useState(color || "");
    const handleColorUpdate = useCallback((event)=>{
        setColorInputValue(event.target.value);
    }, []);
    const handleColorChange = useCallback(()=>{
        const isCorrectColor = /^#([0-9A-F]{3}){1,2}$/i.test(colorInputValue);
        if (!isCorrectColor) {
            if (onChange) {
                onChange("");
            }
            return;
        }
        if (onChange) {
            onChange(colorInputValue);
        }
    }, [
        colorInputValue,
        onChange
    ]);
    return /*#__PURE__*/ _jsxs("div", {
        className: "flex flex-col gap-2",
        children: [
            /*#__PURE__*/ _jsx(HexColorPicker, {
                className: "w-full",
                color: color || "",
                onChange: onChange
            }),
            /*#__PURE__*/ _jsx("input", {
                type: "text",
                className: "w-full p-2 text-black bg-white border rounded dark:bg-black dark:text-white border-neutral-200 dark:border-neutral-800 focus:outline-1 focus:ring-0 focus:outline-neutral-300 dark:focus:outline-neutral-700",
                placeholder: "#000000",
                value: colorInputValue,
                onChange: handleColorUpdate,
                onBlur: handleColorChange
            }),
            /*#__PURE__*/ _jsxs("div", {
                className: "flex flex-wrap items-center gap-1 max-w-[15rem]",
                children: [
                    themeColors.map((currentColor)=>/*#__PURE__*/ _jsx(ColorButton, {
                            active: currentColor === color,
                            color: currentColor,
                            onColorChange: onChange
                        }, currentColor)),
                    /*#__PURE__*/ _jsx(Toolbar.Button, {
                        onClick: onClear,
                        tooltip: i18next.t("resetColorToDefault") || "Reset color to default",
                        children: /*#__PURE__*/ _jsx(Icon, {
                            icon: Undo
                        })
                    })
                ]
            })
        ]
    });
};

//# sourceMappingURL=Colorpicker.js.map