import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Link } from "lucide-react";
import React, { useCallback, useMemo, useState } from "react";
import { Button } from "../../ui/Button/Button.js";
import { Icon } from "../../ui/Icon.js";
import { Surface } from "../../ui/Surface.js";
import { Toggle } from "../../ui/Toggle/Toggle.js";
import i18next from "i18next";
export const useLinkEditorState = ({ initialUrl, initialOpenInNewTab, onSetLink })=>{
    const [url, setUrl] = useState(initialUrl || "");
    const [openInNewTab, setOpenInNewTab] = useState(initialOpenInNewTab || false);
    const onChange = useCallback((event)=>{
        setUrl(event.target.value);
    }, []);
    const isValidUrl = useMemo(()=>/^(\S+):(\/\/)?\S+$/.test(url), [
        url
    ]);
    const handleSubmit = useCallback((e)=>{
        e.preventDefault();
        if (isValidUrl) {
            onSetLink(url, openInNewTab);
        }
    }, [
        url,
        isValidUrl,
        openInNewTab,
        onSetLink
    ]);
    return {
        url,
        setUrl,
        openInNewTab,
        setOpenInNewTab,
        onChange,
        handleSubmit,
        isValidUrl
    };
};
export const LinkEditorPanel = ({ onSetLink, initialOpenInNewTab, initialUrl })=>{
    const state = useLinkEditorState({
        onSetLink,
        initialOpenInNewTab,
        initialUrl
    });
    return /*#__PURE__*/ _jsx(Surface, {
        className: "p-2",
        children: /*#__PURE__*/ _jsxs("div", {
            className: "flex items-center gap-2",
            children: [
                /*#__PURE__*/ _jsxs("label", {
                    className: "flex items-center gap-2 p-2 rounded-lg bg-neutral-100 dark:bg-neutral-900 cursor-text",
                    children: [
                        /*#__PURE__*/ _jsx(Icon, {
                            icon: Link,
                            className: "flex-none text-black dark:text-white"
                        }),
                        /*#__PURE__*/ _jsx("input", {
                            type: "url",
                            className: "flex-1 bg-transparent outline-none min-w-[12rem] text-black text-sm dark:text-white",
                            placeholder: i18next.t("enterUrl") || "Enter URL",
                            value: state.url,
                            onChange: state.onChange
                        })
                    ]
                }),
                /*#__PURE__*/ _jsx(Button, {
                    variant: "primary",
                    buttonSize: "small",
                    type: "button",
                    onClick: (e)=>{
                        state.handleSubmit(e);
                    },
                    disabled: !state.isValidUrl,
                    children: "Set Link"
                }),
                /*#__PURE__*/ _jsx("div", {
                    className: "mt-3",
                    children: /*#__PURE__*/ _jsxs("label", {
                        className: "flex items-center justify-start gap-2 text-sm font-semibold cursor-pointer select-none text-neutral-500 dark:text-neutral-400",
                        children: [
                            "Open in new tab",
                            /*#__PURE__*/ _jsx(Toggle, {
                                active: state.openInNewTab,
                                onChange: state.setOpenInNewTab
                            })
                        ]
                    })
                })
            ]
        })
    });
};

//# sourceMappingURL=LinkEditorPanel.js.map