import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React, { useCallback, useState } from "react";
import { Button } from "../../ui/Button/Button.js";
import { Surface } from "../../ui/Surface.js";
export const useLinkEditorState = ({ initialSrc, onSetLink })=>{
    const [url, setUrl] = useState(initialSrc || "");
    const [isInline, setIsInline] = useState(false);
    const onChange = useCallback((event)=>{
        setUrl(event.target.value);
    }, []);
    // const isValidUrl = useMemo(() => /^(\S+):(\/\/)?\S+$/.test(url), [url]);
    const handleSubmit = useCallback((e)=>{
        e.preventDefault();
        // if (isValidUrl) {
        onSetLink(url, isInline);
    // }
    }, [
        url,
        onSetLink,
        isInline
    ]);
    return {
        url,
        setUrl,
        onChange,
        handleSubmit,
        isInline,
        setIsInline
    };
};
export const SocialMediaEditorPanel = ({ onSetLink, initialOpenInNewTab, initialSrc, placeholderText, buttonText, descriptionText })=>{
    const state = useLinkEditorState({
        onSetLink,
        initialOpenInNewTab,
        initialSrc,
        placeholderText,
        buttonText,
        descriptionText
    });
    return /*#__PURE__*/ _jsx(Surface, {
        className: "p-2",
        children: /*#__PURE__*/ _jsxs("div", {
            className: "flex flex-col items-center gap-2 p-1",
            children: [
                /*#__PURE__*/ _jsx("label", {
                    className: "flex items-center gap-2 p-2 rounded-lg bg-neutral-100 dark:bg-neutral-900 cursor-text w-full",
                    children: /*#__PURE__*/ _jsx("input", {
                        className: "flex-1 bg-transparent outline-none min-w-[276px] text-black text-sm dark:text-white",
                        placeholder: placeholderText,
                        value: state.url,
                        onChange: state.onChange
                    })
                }),
                /*#__PURE__*/ _jsx(Button, {
                    variant: "primary",
                    buttonSize: "medium",
                    className: "w-full m-2",
                    type: "button",
                    onClick: (e)=>{
                        state.handleSubmit(e);
                    },
                    children: buttonText
                }),
                /*#__PURE__*/ _jsx("span", {
                    className: "mt-1 mb-0 text-sm",
                    children: descriptionText
                })
            ]
        })
    });
};

//# sourceMappingURL=SocialMediaEditorPanel.js.map