import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import * as Popover from "@radix-ui/react-popover";
import React, { forwardRef } from "react";
import { cn } from "../../lib/utils/index.js";
import { Surface } from "./Surface.js";
import { Toolbar } from "./Toolbar.js";
export const Trigger = Popover.Trigger;
export const Portal = Popover.Portal;
export const Menu = ({ customTrigger, trigger, triggerClassName, children, isOpen, withPortal, tooltip, onOpenChange })=>{
    return /*#__PURE__*/ _jsxs(Popover.Root, {
        onOpenChange: onOpenChange,
        children: [
            customTrigger ? /*#__PURE__*/ _jsx(Trigger, {
                asChild: true,
                children: trigger
            }) : /*#__PURE__*/ _jsx(Trigger, {
                asChild: true,
                children: /*#__PURE__*/ _jsx(Toolbar.Button, {
                    type: "button",
                    className: triggerClassName,
                    tooltip: !isOpen ? tooltip : "",
                    children: trigger
                })
            }),
            withPortal ? /*#__PURE__*/ _jsx(Popover.Portal, {
                children: /*#__PURE__*/ _jsx(Popover.Content, {
                    asChild: true,
                    sideOffset: 8,
                    children: /*#__PURE__*/ _jsx(Surface, {
                        className: "min-w-[15rem] p-2 flex flex-col gap-0.5 max-h-80 overflow-auto z-[9999]",
                        children: children
                    })
                })
            }) : /*#__PURE__*/ _jsx(Popover.Content, {
                asChild: true,
                sideOffset: 8,
                children: /*#__PURE__*/ _jsx(Surface, {
                    className: "min-w-[15rem] p-2 flex flex-col gap-0.5 max-h-80 overflow-auto z-[9999]",
                    children: children
                })
            })
        ]
    });
};
Menu.displayName = "Menu";
export const Item = ({ label, close = true, icon, iconComponent, disabled, onClick, isActive })=>{
    const className = cn("flex items-center gap-2 p-1.5 text-sm font-medium text-neutral-500 text-left bg-transparent w-full rounded  outline-none", !isActive && !disabled, "hover:bg-neutral-100 hover:text-neutral-800 dark:hover:bg-neutral-900 dark:hover:text-neutral-200", isActive && !disabled && "bg-neutral-100 text-neutral-800 dark:bg-neutral-900 dark:text-neutral-200", disabled && "text-neutral-400 cursor-not-allowed dark:text-neutral-600");
    const IconComponent = icon ? icon : null;
    const IconCustomComponent = iconComponent || null;
    const ItemComponent = close ? Popover.Close : "button";
    return /*#__PURE__*/ _jsxs(ItemComponent, {
        className: className,
        onClick: onClick,
        disabled: disabled,
        children: [
            IconComponent && /*#__PURE__*/ _jsx(IconComponent, {
                className: "w-4 h-4"
            }),
            IconCustomComponent,
            label
        ]
    });
};
export const CategoryTitle = ({ children })=>{
    return /*#__PURE__*/ _jsx("div", {
        className: "mt-4 first:mt-1.5 mb-1.5 text-[0.625rem] font-medium text-neutral-400 dark:text-neutral-600 uppercase select-none px-1",
        children: children
    });
};
export const Divider = /*#__PURE__*/ forwardRef((props, ref)=>{
    return /*#__PURE__*/ _jsx("hr", {
        ...props,
        ref: ref,
        className: "my-1 border-neutral-200 dark:border-neutral-800"
    });
});
Divider.displayName = "Divider";

//# sourceMappingURL=PopoverMenu.js.map