import { jsx as _jsx } from "react/jsx-runtime";
import { forwardRef } from "react";
import { cn } from "../../lib/utils/index.js";
import { SpanButton } from "./Button/SpanButton.js";
import { Surface } from "./Surface.js";
import Tooltip from "./Tooltip/index.js";
const ToolbarWrapper = /*#__PURE__*/ forwardRef(({ shouldShowContent = true, children, isVertical = false, className, ...rest }, ref)=>{
    const toolbarClassName = cn("text-black inline-flex h-full leading-none gap-0.5", isVertical ? "flex-col p-2" : "flex-row p-1 items-center", className);
    return shouldShowContent && /*#__PURE__*/ _jsx(Surface, {
        className: toolbarClassName,
        ...rest,
        ref: ref,
        children: children
    });
});
ToolbarWrapper.displayName = "Toolbar";
const ToolbarDivider = /*#__PURE__*/ forwardRef(({ horizontal, className, ...rest }, ref)=>{
    const dividerClassName = cn("bg-neutral-200 dark:bg-neutral-800", horizontal ? "w-full min-w-[1.5rem] h-[1px] my-1 first:mt-0 last:mt-0" : "h-full min-h-[1.5rem] w-[1px] mx-1 first:ml-0 last:mr-0", className);
    return /*#__PURE__*/ _jsx("div", {
        className: dividerClassName,
        ref: ref,
        ...rest
    });
});
ToolbarDivider.displayName = "Toolbar.Divider";
const ToolbarButton = /*#__PURE__*/ forwardRef(({ children, buttonSize = "icon", variant = "ghost", className, tooltip, tooltipShortcut, activeClassname, ...rest }, ref)=>{
    const buttonClass = cn("gap-1 min-w-[2rem] px-2 w-auto", className);
    const content = /*#__PURE__*/ _jsx(SpanButton, {
        activeClassname: activeClassname,
        className: buttonClass,
        variant: variant,
        buttonSize: buttonSize,
        ref: ref,
        ...rest,
        children: children
    });
    if (tooltip) {
        return /*#__PURE__*/ _jsx(Tooltip, {
            title: tooltip,
            shortcut: tooltipShortcut,
            children: content
        });
    }
    return content;
});
ToolbarButton.displayName = "ToolbarButton";
export const Toolbar = {
    Wrapper: ToolbarWrapper,
    Divider: ToolbarDivider,
    Button: ToolbarButton
};

//# sourceMappingURL=Toolbar.js.map